@@ -3,7 +3,7 @@
 use crate::co::CCM;
 
 pub_struct_const! { MB, u32,
-	/// [`HWND::MessageBox`](crate::HWND::MessageBox) `uType` (`u32`).
+	/// [`HWND::MessageBox`](crate::HWND::MessageBox) `flags` (`u32`).
 	=>
 	/// The message box contains three push buttons: Abort, Retry, and Ignore.
 	ABORTRETRYIGNORE, 0x0000_0002
@@ -135,7 +135,7 @@ pub_struct_const! { MB, u32,
 }
 
 pub_struct_const! { MBC, u32,
-	/// [`MultiByteToWideChar`](crate::MultiByteToWideChar) `dwFlags` (`u32`).
+	/// [`MultiByteToWideChar`](crate::MultiByteToWideChar) `flags` (`u32`).
 	/// Originally has `MB` prefix.
 	=>
 	/// None of the actual values (zero).
@@ -238,8 +238,9 @@ pub_struct_const_ws! { MCS, u32,
 }
 
 pub_struct_const! { MF, u32,
-	/// [`HMENU::AppendMenu`](crate::HMENU::AppendMenu) `uFlags`,
-	/// [`HMENU::GetMenuState`](crate::HMENU::GetMenuState) return value
+	/// [`HMENU::AppendMenu`](crate::HMENU::AppendMenu) `flags`,
+	/// [`HMENU::GetMenuState`](crate::HMENU::GetMenuState) return value,
+	/// [`HWND::HiliteMenuItem`](crate::HWND::HiliteMenuItem) `hilite`
 	/// (`u32`).
 	=>
 	INSERT, 0x0000_0000
@@ -351,6 +352,25 @@ pub_struct_const! { MNS, u32,
 	CHECKORBMP, 0x0400_0000
 }
 
+pub_struct_const! { MONITOR, u32,
+	/// [`HMONITOR::MonitorFromPoint`](crate::HMONITOR::MonitorFromPoint),
+	/// [`HMONITOR::MonitorFromRect`](crate::HMONITOR::MonitorFromRect),
+	/// [`HWND::MonitorFromWindow`](crate::HWND::MonitorFromWindow) flags
+	/// (`u32`).
+	=>
+	DEFAULTTONULL, 0x0000_0000
+	DEFAULTTOPRIMARY, 0x0000_0001
+	DEFAULTTONEAREST, 0x0000_0002
+}
+
+pub_struct_const! { MONITORINFOF, u32,
+	/// [`MONITORINFO`](crate::MONITORINFO) `dwFlags` (`u32`).
+	=>
+	/// None of the actual values (zero).
+	NoValue, 0
+	PRIMARY, 0x0000_0001
+}
+
 pub_struct_const! { MSGF, u8,
 	/// [`wm::EnterIdle`](crate::msg::wm::EnterIdle) reason (`u8`).
 	=>
@@ -385,7 +405,7 @@ pub_struct_const! { NIIF, u32,
 }
 
 pub_struct_const! { NIM, u32,
-	/// [`Shell_NotifyIcon`](crate::Shell_NotifyIcon) `dwMessage` (`u32`).
+	/// [`Shell_NotifyIcon`](crate::Shell_NotifyIcon) `message` (`u32`).
 	=>
 	ADD, 0x0000_0000
 	MODIFY, 0x0000_0001
