@@ -1,6 +1,6 @@
 #![allow(non_camel_case_types, non_upper_case_globals)]
 
-use crate::co::{CCM, FF, WM};
+use crate::co::{ACCESS_RIGHTS, CCM, FF, STANDARD_RIGHTS, WM};
 
 pub_struct_const! { OBJID, u32,
 	/// [`HWND::GetMenuBarInfo`](crate::HWND::GetMenuBarInfo) `idObject` (`i32`).
@@ -76,6 +76,7 @@ pub_struct_const! { ODT_C, u32,
 }
 
 pub_struct_const! { OUT_PRECIS, u8,
+	/// [`HFONT::CreateFont`](crate::HFONT::CreateFont) `out_precision` and
 	/// [`LOGFONT`](crate::LOGFONT) `lfOutPrecision` (`u8`).
 	=>
 	DEFAULT, 0
@@ -92,8 +93,8 @@ pub_struct_const! { OUT_PRECIS, u8,
 }
 
 pub_struct_const! { PAGE, u32,
-	/// [`HFILE::CreateFileMapping`](crate::HFILE::CreateFileMapping)
-	/// `flProtect` (`u32`).
+	/// [`HFILE::CreateFileMapping`](crate::HFILE::CreateFileMapping) `protect`
+	/// (`u32`).
 	=>
 	/// Allows views to be mapped for read-only, copy-on-write, or execute
 	/// access.
@@ -194,6 +195,7 @@ pub_struct_const! { PBST, u32,
 }
 
 pub_struct_const! { PITCH, u8,
+	/// [`HFONT::CreateFont`](crate::HFONT::CreateFont) `pitch_and_family` and
 	/// [`LOGFONT`](crate::LOGFONT) `lfPitchAndFamily` (`u8`), used with
 	/// [`FF`](crate::co::FF).
 	=>
@@ -210,7 +212,7 @@ impl PITCH {
 }
 
 pub_struct_const! { PM, u32,
-	/// [`PeekMessage`](crate::PeekMessage) `wRemoveMsg` (`u32`).
+	/// [`PeekMessage`](crate::PeekMessage) `remove_msg` (`u32`).
 	=>
 	NOREMOVE, 0x0000
 	REMOVE, 0x0001
@@ -222,6 +224,42 @@ pub_struct_const! { PM, u32,
 	QS_SENDMESSAGE, QS::SENDMESSAGE.0 << 16
 }
 
+pub_struct_const! { PROCESS, u32,
+	/// Process
+	/// [security and access rights](https://docs.microsoft.com/en-us/windows/win32/procthread/process-security-and-access-rights)
+	/// (`u32`).
+	=>
+	DELETE, ACCESS_RIGHTS::DELETE.0
+	READ_CONTROL, ACCESS_RIGHTS::READ_CONTROL.0
+	SYNCHRONIZE, ACCESS_RIGHTS::SYNCHRONIZE.0
+	WRITE_DAC, ACCESS_RIGHTS::WRITE_DAC.0
+	WRITE_OWNER, ACCESS_RIGHTS::WRITE_OWNER.0
+
+	ALL_ACCESS, STANDARD_RIGHTS::REQUIRED.0 | ACCESS_RIGHTS::SYNCHRONIZE.0 | 0xffff
+	CREATE_PROCESS, 0x0080
+	CREATE_THREAD, 0x0002
+	DUP_HANDLE, 0x0040
+	QUERY_INFORMATION, 0x0400
+	QUERY_LIMITED_INFORMATION, 0x1000
+	SET_INFORMATION, 0x0200
+	SET_QUOTA, 0x0100
+	SUSPEND_RESUME, 0x0800
+	TERMINATE, 0x0001
+	WM_OPERATION, 0x0008
+	VM_READ, 0x0010
+	VM_WRITE, 0x0020
+}
+
+pub_struct_const! { PROCESS_NAME, u32,
+	/// [`QueryFullProcessImageName`](crate::HPROCESS::QueryFullProcessImageName)
+	/// flags (`u32`).
+	=>
+	/// The name should use the Win32 path format.
+	WIN32, 0
+	/// The name should use the native system path format.
+	NATIVE, 0x0000_0001
+}
+
 pub_struct_const! { PROCESSOR, u32,
 	/// [`SYSTEM_INFO`](crate::SYSTEM_INFO) `dwProcessorType` (`u32`).
 	=>
@@ -272,7 +310,7 @@ pub_struct_const! { PROCESSOR_ARCHITECTURE, u16,
 }
 
 pub_struct_const! { PS, i32,
-	/// [`HPEN::CreatePen`](crate::HPEN::CreatePen) `iStyle` (`i32`).
+	/// [`HPEN::CreatePen`](crate::HPEN::CreatePen) `style` (`i32`).
 	=>
 	SOLID, 0
 	DASH, 1
@@ -284,6 +322,7 @@ pub_struct_const! { PS, i32,
 }
 
 pub_struct_const! { QUALITY, u8,
+	/// [`HFONT::CreateFont`](crate::HFONT::CreateFont) `quality` and
 	/// [`LOGFONT`](crate::LOGFONT) `lfQuality` (`u8`).
 	=>
 	DEFAULT, 0
@@ -441,8 +480,10 @@ pub_struct_const! { REG, u32,
 }
 
 pub_struct_const! { REG_OPTION, u32,
-	/// [`HKEY::RegOpenKeyEx`](crate::HKEY::RegOpenKeyEx) `uOptions` (`u32`).
+	/// [`HKEY::OpenKeyEx`](crate::HKEY::OpenKeyEx) `options` (`u32`).
 	=>
+	/// None of the actual values (zero).
+	NoValue, 0
 	RESERVED, 0x0000_0000
 	NON_VOLATILE, 0x0000_0000
 	VOLATILE, 0x0000_0001
@@ -462,6 +503,14 @@ pub_struct_const! { REGION, i32,
 	COMPLEX, 3
 }
 
+pub_struct_const! { REPLACEFILE, u32,
+	/// [`ReplaceFile`](crate::ReplaceFile) `flags` (`u32`).
+	=>
+	WRITE_THROUGH, 0x0000_0001
+	IGNORE_MERGE_ERRORS, 0x0000_0002
+	IGNORE_ACL_ERRORS, 0x0000_0004
+}
+
 pub_struct_const! { ROP, u32,
 	/// Raster operation code (`u32`).
 	/// [`HDC::BitBlt`](crate::HDC::BitBlt) `rop`,
@@ -489,7 +538,7 @@ pub_struct_const! { ROP, u32,
 }
 
 pub_struct_const! { RRF, u32,
-	/// [`HKEY::RegGetValue`](crate::HKEY::RegGetValue) `dwFlags` (`u32`).
+	/// [`HKEY::GetValue`](crate::HKEY::GetValue) `dwFlags` (`u32`).
 	=>
 	RT_REG_NONE, 0x0000_0001
 	RT_REG_SZ, 0x0000_0002
