@@ -58,16 +58,17 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::ConvertTimeFormat`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-converttimeformat)
 			/// method.
 			pub fn ConvertTimeFormat(&self,
-				targetFormat: &GUID, source: i64, sourceFormat: &GUID) -> WinResult<i64>
+				target_format: &GUID,
+				source: i64, source_format: &GUID) -> WinResult<i64>
 			{
 				let mut target: i64 = 0;
 				hr_to_winresult(
 					(self.imediaseeking_vt().ConvertTimeFormat)(
 						self.ppvt,
 						&mut target,
-						targetFormat as *const _ as _,
+						target_format as *const _ as _,
 						source,
-						sourceFormat as *const _ as _,
+						source_format as *const _ as _,
 					),
 				).map(|_| target)
 			}
@@ -77,8 +78,7 @@ macro_rules! impl_IMediaSeeking {
 			///
 			/// Returns earliest and latest times for efficient seeking.
 			pub fn GetAvailable(&self) -> WinResult<(i64, i64)> {
-				let mut early: i64 = 0;
-				let mut late: i64 = 0;
+				let (mut early, mut late) = (i64::default(), i64::default());
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetPositions)(
 						self.ppvt,
@@ -91,7 +91,7 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetCurrentPosition method`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-getcurrentposition)
 			/// method.
 			pub fn GetCurrentPosition(&self) -> WinResult<i64> {
-				let mut pos: i64 = 0;
+				let mut pos = i64::default();
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetCurrentPosition)(
 						self.ppvt,
@@ -103,7 +103,7 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetDuration`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-getduration)
 			/// method.
 			pub fn GetDuration(&self) -> WinResult<i64> {
-				let mut duration: i64 = 0;
+				let mut duration = i64::default();
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetDuration)(self.ppvt, &mut duration),
 				).map(|_| duration)
@@ -114,8 +114,7 @@ macro_rules! impl_IMediaSeeking {
 			///
 			/// Returns current and stop positions.
 			pub fn GetPositions(&self) -> WinResult<(i64, i64)> {
-				let mut current: i64 = 0;
-				let mut stop: i64 = 0;
+				let (mut current, mut stop) = (i64::default(), i64::default());
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetPositions)(
 						self.ppvt,
@@ -128,7 +127,7 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetPreroll`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-getpreroll)
 			/// method.
 			pub fn GetPreroll(&self) -> WinResult<i64> {
-				let mut preroll: i64 = 0;
+				let mut preroll = i64::default();
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetPreroll)(self.ppvt, &mut preroll),
 				).map(|_| preroll)
@@ -137,7 +136,7 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetRate`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-getrate)
 			/// method.
 			pub fn GetRate(&self) -> WinResult<f64> {
-				let mut rate: f64 = 0.0;
+				let mut rate = f64::default();
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetRate)(self.ppvt, &mut rate),
 				).map(|_| rate)
@@ -146,7 +145,7 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetStopPosition`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-getstopposition)
 			/// method.
 			pub fn GetStopPosition(&self) -> WinResult<i64> {
-				let mut pos: i64 = 0;
+				let mut pos = i64::default();
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetStopPosition)(self.ppvt, &mut pos),
 				).map(|_| pos)
@@ -155,28 +154,28 @@ macro_rules! impl_IMediaSeeking {
 			/// [`IMediaSeeking::GetTimeFormat`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-gettimeformat)
 			/// method.
 			pub fn GetTimeFormat(&self) -> WinResult<GUID> {
-				let mut timeGuid = guid::TIME_FORMAT_NONE;
+				let mut time_guid = guid::TIME_FORMAT_NONE;
 				hr_to_winresult(
 					(self.imediaseeking_vt().GetStopPosition)(
 						self.ppvt,
-						&mut timeGuid as *mut _ as _,
+						&mut time_guid as *mut _ as _,
 					),
-				).map(|_| timeGuid)
+				).map(|_| time_guid)
 			}
 
 			/// [`IMediaSeeking::SetPositions`](https://docs.microsoft.com/en-us/windows/win32/api/strmif/nf-strmif-imediaseeking-setpositions)
 			/// method.
 			pub fn SetPositions(&self,
-				mut current: i64, currentFlags: dshowco::SEEKING_FLAGS,
-				mut stop: i64, stopFlags: dshowco::SEEKING_FLAGS) -> WinResult<()>
+				mut current: i64, current_flags: dshowco::SEEKING_FLAGS,
+				mut stop: i64, stop_flags: dshowco::SEEKING_FLAGS) -> WinResult<()>
 			{
 				match co::ERROR(
 					(self.imediaseeking_vt().SetPositions)(
 						self.ppvt,
 						&mut current,
-						currentFlags.0,
+						current_flags.0,
 						&mut stop,
-						stopFlags.0,
+						stop_flags.0,
 					) as _,
 				) {
 					co::ERROR::S_OK | co::ERROR::S_FALSE => Ok(()),
