@@ -51,16 +51,18 @@ macro_rules! impl_IDispatch {
 
 			/// [`IDispatch::GetTypeInfo`](https://docs.microsoft.com/en-us/windows/win32/api/oaidl/nf-oaidl-idispatch-gettypeinfo)
 			/// method.
-			pub fn GetTypeInfo(&self, iTInfo: u32, lcid: LCID) -> WinResult<ITypeInfo> {
-				let mut ppvQueried: PPVT = std::ptr::null_mut();
+			pub fn GetTypeInfo(&self,
+				info_type: u32, lcid: LCID) -> WinResult<ITypeInfo>
+			{
+				let mut ppv_queried: PPVT = std::ptr::null_mut();
 				hr_to_winresult(
 					(self.idispatch_vt().GetTypeInfo)(
 						self.ppvt,
-						iTInfo,
+						info_type,
 						lcid.0,
-						&mut ppvQueried as *mut _ as _,
+						&mut ppv_queried as *mut _ as _,
 					),
-				).map(|_| ITypeInfo::from(ppvQueried))
+				).map(|_| ITypeInfo::from(ppv_queried))
 			}
 		}
 	};
