@@ -179,7 +179,7 @@ impl HwndHmenu {
 
 /// Variant parameter for:
 ///
-/// * [`HWND::SetWindowPos`](crate::HWND::SetWindowPos) `hWndInsertAfter`.
+/// * [`HWND::SetWindowPos`](crate::HWND::SetWindowPos) `hwnd_insert_after`.
 #[derive(Copy, Clone)]
 pub enum HwndPlace {
 	/// A handle to the window to precede the positioned window in the Z order.
@@ -225,9 +225,21 @@ impl HwndPointId {
 
 /// Variant parameter for:
 ///
-/// * [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `hMainIcon`;
 /// * [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `hFooterIcon`.
-#[derive(Copy, Clone)]
+#[derive(Clone)]
+pub enum IconId {
+	/// No icon.
+	None,
+	/// An icon handle.
+	Icon(HICON),
+	/// A resource ID.
+	Id(u16),
+}
+
+/// Variant parameter for:
+///
+/// * [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `hMainIcon`.
+#[derive(Clone)]
 pub enum IconIdTdicon {
 	/// No icon.
 	None,
@@ -241,7 +253,7 @@ pub enum IconIdTdicon {
 
 /// Variant parameter for:
 ///
-/// * [`HINSTANCE::LoadCursor`](crate::HINSTANCE::LoadCursor) `lpCursorName`.
+/// * [`HINSTANCE::LoadCursor`](crate::HINSTANCE::LoadCursor) `resource_id`.
 #[derive(Clone)]
 pub enum IdIdcStr {
 	/// A resource ID.
@@ -266,7 +278,7 @@ impl IdIdcStr {
 
 /// Variant parameter for:
 ///
-/// * [`HINSTANCE::LoadIcon`](crate::HINSTANCE::LoadIcon) `lpIconName`.
+/// * [`HINSTANCE::LoadIcon`](crate::HINSTANCE::LoadIcon) `icon_id`.
 #[derive(Clone)]
 pub enum IdIdiStr {
 	/// A resource ID.
@@ -373,8 +385,13 @@ impl IdPos {
 
 /// Variant parameter for:
 ///
+/// * [`HINSTANCE::CreateDialogParam`](crate::HINSTANCE::CreateDialogParam) `resource_id`;
+/// * [`HINSTANCE::DialogBoxParam`](crate::HINSTANCE::DialogBoxParam) `resource_id`;
 /// * [`HINSTANCE::EnumResourceNames`](crate::HINSTANCE::EnumResourceNames) `func`;
-/// * [`HINSTANCE::LoadAccelerators`](crate::HINSTANCE::LoadAccelerators) `lpTableName`.
+/// * [`HINSTANCE::FindResource`](crate::HINSTANCE::FindResource) `resource_id`;
+/// * [`HINSTANCE::FindResourceEx`](crate::HINSTANCE::FindResourceEx) `resource_id`;
+/// * [`HINSTANCE::LoadAccelerators`](crate::HINSTANCE::LoadAccelerators) `table_name`;
+/// * [`HINSTANCE::LoadMenu`](crate::HINSTANCE::LoadMenu) `resource_id`;
 #[derive(Clone)]
 pub enum IdStr {
 	/// A resource ID.
@@ -424,7 +441,7 @@ impl IdTdiconStr {
 		match self {
 			Self::None => std::ptr::null(),
 			Self::Id(id) => MAKEINTRESOURCE(*id as _),
-			Self::Tdicon(tdi) => MAKEINTRESOURCE(tdi.0),
+			Self::Tdicon(tdi) => MAKEINTRESOURCE(tdi.0 as _),
 			Self::Str(ws) => unsafe { ws.as_ptr() },
 		}
 	}
@@ -479,7 +496,7 @@ pub enum NccspRect<'a, 'b> {
 	Rect(&'b mut RECT),
 }
 
-/// Variant value returned by [`RegQueryValueEx`](crate::HKEY::RegQueryValueEx).
+/// Registry value types.
 #[derive(Clone)]
 pub enum RegistryValue {
 	/// Binary value, defined as [`REG::BINARY`](crate::co::REG::BINARY).
@@ -536,7 +553,10 @@ impl RegistryValue {
 
 /// Variant parameter for:
 ///
-/// * [`HINSTANCE::EnumResourceTypes`](crate::HINSTANCE::EnumResourceTypes) `func`.
+/// * [`HINSTANCE::EnumResourceLanguages`](crate::HINSTANCE::EnumResourceLanguages) `resource_type`;
+/// * [`HINSTANCE::EnumResourceTypes`](crate::HINSTANCE::EnumResourceTypes) `resource_type`;
+/// * [`HINSTANCE::FindResource`](crate::HINSTANCE::FindResource) `resource_type`;
+/// * [`HINSTANCE::FindResourceEx`](crate::HINSTANCE::FindResourceEx) `resource_type`.
 #[derive(Clone)]
 pub enum RtStr {
 	/// A predefined resource ID.
