@@ -1,9 +1,10 @@
 use std::ptr::NonNull;
 
-use crate::aliases::WinResult;
+use crate::aliases::{BoxResult, WinResult};
 use crate::co;
 use crate::funcs::{DispatchMessage, GetMessage, TranslateMessage};
 use crate::gui::events::{ProcessResult, WindowEvents};
+use crate::gui::privs::{post_quit_error, QUIT_ERROR};
 use crate::handles::{HACCEL, HINSTANCE, HWND};
 use crate::msg::WndMsg;
 use crate::structs::MSG;
@@ -69,30 +70,32 @@ impl Base {
 		&self.privileged_events
 	}
 
-	pub(in crate::gui) fn process_effective_message(&mut self,
-		wm_any: WndMsg) -> ProcessResult
+	pub(in crate::gui) fn process_one_message(&mut self,
+		wm_any: WndMsg) -> BoxResult<ProcessResult>
 	{
-		self.user_events.process_effective_message(wm_any)
+		self.user_events.process_one_message(wm_any)
 	}
 
 	pub(in crate::gui) fn process_privileged_messages(&mut self,
-		wm_any: WndMsg)
+		wm_any: WndMsg) -> BoxResult<()>
 	{
-		self.privileged_events.process_all_messages(wm_any);
+		self.privileged_events.process_all_messages(wm_any)
 	}
 
 	pub(in crate::gui) fn ui_thread_message_handler(&self) {
 		self.privileged_events.wm(Self::WM_UI_THREAD, |p| {
 			if co::WM(p.wparam as _) == Self::WM_UI_THREAD { // additional safety check
-				let ptr_pack = p.lparam as *mut Box<dyn FnOnce()>;
-				let pack: Box<Box<dyn FnOnce()>> = unsafe { Box::from_raw(ptr_pack) };
-				pack();
+				let ptr_pack = p.lparam as *mut Box<dyn FnOnce() -> BoxResult<()>>;
+				let pack: Box<Box<dyn FnOnce() -> BoxResult<()>>> = unsafe { Box::from_raw(ptr_pack) };
+				pack().unwrap_or_else(|err| post_quit_error(err));
 			}
-			0
+			Ok(0)
 		});
 	}
 
-	pub(in crate::gui) fn run_ui_thread<F: FnOnce()>(&self, func: F) {
+	pub(in crate::gui) fn run_ui_thread<F>(&self, func: F)
+		where F: FnOnce() -> BoxResult<()>,
+	{
 		// This method is analog to SendMessage (synchronous), but intended to
 		// be called from another thread, so a callback function can, tunelled
 		// by wndproc, run in the original thread of the window, thus allowing
@@ -100,7 +103,7 @@ impl Base {
 		// WM_ message.
 
 		// https://users.rust-lang.org/t/sending-a-boxed-trait-over-ffi/21708/2
-		let pack: Box<Box<dyn FnOnce()>> = Box::new(Box::new(func));
+		let pack: Box<Box<dyn FnOnce() -> BoxResult<()>>> = Box::new(Box::new(func));
 		let ptr_pack = Box::into_raw(pack);
 		self.hwnd.SendMessage(WndMsg {
 			msg_id: Self::WM_UI_THREAD,
@@ -110,7 +113,7 @@ impl Base {
 	}
 
 	pub(in crate::gui) fn run_main_loop(
-		haccel: Option<HACCEL>) -> WinResult<()>
+		haccel: Option<HACCEL>) -> BoxResult<i32>
 	{
 		loop {
 			let mut msg = MSG::default();
@@ -118,9 +121,9 @@ impl Base {
 				// WM_QUIT was sent, gracefully terminate the program.
 				// wParam has the program exit code.
 				// https://docs.microsoft.com/en-us/windows/win32/winmsg/using-messages-and-message-queues
-				return match co::ERROR(msg.wParam as _) {
-					co::ERROR::SUCCESS => Ok(()),
-					err => Err(err),
+				return match unsafe { QUIT_ERROR.take() } {
+					Some(err) => Err(err),
+					None => Ok(msg.wParam as _),
 				};
 			}
 
