@@ -1,13 +1,12 @@
 use std::sync::Arc;
 
-use crate::aliases::WinResult;
+use crate::aliases::BoxResult;
 use crate::co;
 use crate::enums::HwndPlace;
-use crate::funcs::PostQuitMessage;
 use crate::gui::base::Base;
 use crate::gui::dlg_base::DlgBase;
 use crate::gui::privs::{auto_ctrl_id, multiply_dpi, paint_control_borders};
-use crate::structs::POINT;
+use crate::structs::{POINT, SIZE};
 
 #[derive(Clone)]
 pub(in crate::gui) struct DlgControl(Arc<Obj>);
@@ -43,42 +42,43 @@ impl DlgControl {
 		self.0.base.base_ref()
 	}
 
-	pub(in crate::gui) fn run_ui_thread<F: FnOnce()>(&self, func: F) {
+	pub(in crate::gui) fn run_ui_thread<F>(&self, func: F)
+		where F: FnOnce() -> BoxResult<()>,
+	{
 		self.0.base.run_ui_thread(func);
 	}
 
 	fn default_message_handlers(&self, parent_base_ref: &Base) {
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let self2 = self.clone();
-			move |p| {
-				|_| -> WinResult<isize> {
-					// Create the control.
-					self2.0.base.create_dialog_param()?; // may panic
+			move |_| {
+				// Create the control.
+				self2.0.base.create_dialog_param()?; // may panic
 
-					// Set control position within parent.
-					let mut dlg_pos = self2.0.position;
-					multiply_dpi(Some(&mut dlg_pos), None)?;
-					self2.base_ref().hwnd_ref().SetWindowPos(
-						HwndPlace::None,
-						dlg_pos.x, dlg_pos.y, 0, 0,
-						co::SWP::NOZORDER | co::SWP::NOSIZE,
-					)?;
+				// Set control position within parent.
+				let mut dlg_pos = self2.0.position;
+				multiply_dpi(Some(&mut dlg_pos), None)?;
+				self2.base_ref().hwnd_ref().SetWindowPos(
+					HwndPlace::None,
+					dlg_pos, SIZE::default(),
+					co::SWP::NOZORDER | co::SWP::NOSIZE,
+				)?;
 
-					// Give the control an ID.
-					self2.base_ref().hwnd_ref().SetWindowLongPtr(
-						co::GWLP::ID,
-						self2.0.ctrl_id.unwrap_or_else(|| auto_ctrl_id()) as _,
-					);
-					Ok(0)
-				}
-				(p).unwrap_or_else(|err| { PostQuitMessage(err); 0 })
+				// Give the control an ID.
+				self2.base_ref().hwnd_ref().SetWindowLongPtr(
+					co::GWLP::ID,
+					self2.0.ctrl_id.unwrap_or_else(|| auto_ctrl_id()) as _,
+				);
+				Ok(0)
 			}
 		});
 
 		self.base_ref().user_events_ref().wm_nc_paint({
 			let self2 = self.clone();
-			move |p| paint_control_borders(*self2.base_ref().hwnd_ref(), p)
-				.unwrap_or_else(|err| PostQuitMessage(err))
+			move |p| {
+				paint_control_borders(*self2.base_ref().hwnd_ref(), p)?;
+				Ok(())
+			}
 		});
 	}
 }
