@@ -1,3 +1,4 @@
+use crate::aliases::BoxResult;
 use crate::co;
 use crate::structs::{NMBCDROPDOWN, NMBCHOTITEM, NMCUSTOMDRAW};
 
@@ -39,14 +40,15 @@ impl ButtonEvents {
 		/// # Examples
 		///
 		/// ```rust,ignore
-		/// use winsafe::gui::Button;
+		/// use winsafe::{gui, BoxResult};
 		///
-		/// let btn: Button; // initialized somewhere
+		/// let btn: gui::Button; // initialized somewhere
 		///
 		/// btn.on().bn_clicked({
 		///     let btn = btn.clone(); // pass into the closure
-		///     move || {
+		///     move || -> BoxResult<()> {
 		///         println!("HWND: {}", btn.hwnd());
+		///         Ok(())
 		///     }
 		/// });
 		/// ```
@@ -88,9 +90,9 @@ impl ButtonEvents {
 	///
 	/// Notifies about custom draw operations on the button.
 	pub fn nm_custom_draw<F>(&self, func: F)
-		where F: Fn(&NMCUSTOMDRAW) -> co::CDRF + 'static,
+		where F: Fn(&NMCUSTOMDRAW) -> BoxResult<co::CDRF> + 'static,
 	{
 		self.parent_user_events().add_nfy(self.ctrl_id as _, co::NM::CUSTOMDRAW,
-			move |p| Some(func(unsafe { p.cast_nmhdr::<NMCUSTOMDRAW>() }).into()));
+			move |p| Ok(Some(func(unsafe { p.cast_nmhdr::<NMCUSTOMDRAW>() })?.into())));
 	}
 }
