@@ -1,6 +1,7 @@
 use std::ptr::NonNull;
 use std::rc::Rc;
 
+use crate::aliases::BoxResult;
 use crate::co;
 use crate::gui::base::Base;
 use crate::gui::events::WindowEvents;
@@ -43,23 +44,24 @@ impl RadioGroupEvents {
 	/// # Examples
 	///
 	/// ```rust,ignore
-	/// use winsafe::gui::{RadioGroup, WindowMain};
+	/// use winsafe::{gui, BoxResult};
 	///
-	/// let wnd: WindowMain; // initialized somewhere
-	/// let radios: RadioGroup;
+	/// let wnd: gui::WindowMain; // initialized somewhere
+	/// let radios: gui::RadioGroup;
 	///
 	/// radios.on().bn_clicked({
 	///     let radios = radios.clone();
-	///     move || {
+	///     move || -> BoxResult<()> {
 	///         println!("Selected {}",
 	///             rads.checked().unwrap()
-	///                 .hwnd().GetWindowText().unwrap(),
+	///                 .hwnd().GetWindowText()?,
 	///         );
+	///         Ok(())
 	///     }
 	/// });
 	/// ```
 	pub fn bn_clicked<F>(&self, func: F)
-		where F: Fn() + 'static,
+		where F: Fn() -> BoxResult<()> + 'static,
 	{
 		let shared_func = Rc::new(VeryUnsafeCell::new(func));
 
@@ -80,7 +82,7 @@ impl RadioGroupEvents {
 	/// [`BS::OWNERDRAW`](crate::co::BS::OWNERDRAW) buttons. Other button types
 	/// send only if they have the [`BS::NOTIFY`](crate::co::BS::NOTIFY) style.
 	pub fn bn_dbl_clk<F>(&self, func: F)
-		where F: Fn() + 'static,
+		where F: Fn() -> BoxResult<()> + 'static,
 	{
 		let shared_func = Rc::new(VeryUnsafeCell::new(func));
 
@@ -99,7 +101,7 @@ impl RadioGroupEvents {
 	/// [`BS::NOTIFY`](crate::co::BS::NOTIFY) style to send this notification
 	/// code.
 	pub fn bn_kill_focus<F>(&self, func: F)
-		where F: Fn() + 'static,
+		where F: Fn() -> BoxResult<()> + 'static,
 	{
 		let shared_func = Rc::new(VeryUnsafeCell::new(func));
 
@@ -118,7 +120,7 @@ impl RadioGroupEvents {
 	/// [`BS::NOTIFY`](crate::co::BS::NOTIFY) style to send this notification
 	/// code.
 	pub fn bn_set_focus<F>(&self, func: F)
-		where F: Fn() + 'static,
+		where F: Fn() -> BoxResult<()> + 'static,
 	{
 		let shared_func = Rc::new(VeryUnsafeCell::new(func));
 
