@@ -1,3 +1,4 @@
+use crate::aliases::BoxResult;
 use crate::co;
 
 pub_struct_ctrl_events_proxy! {
@@ -43,15 +44,15 @@ impl EditEvents {
 		/// # Examples
 		///
 		/// ```rust,ignore
-		/// use winsafe::gui::Edit;
+		/// use winsafe::{gui, BoxResult};
 		///
-		/// let txt: Edit; // initialized somewhere
+		/// let txt: gui::Edit; // initialized somewhere
 		///
 		/// txt.on().en_change({
 		///     let txt = txt.clone(); // pass into the closure
-		///     move || {
-		///         println!("Text: {}",
-		///             btn.hwnd().GetWindowText().unwrap());
+		///     move || -> BoxResult<()> {
+		///         println!("Text: {}", btn.hwnd().GetWindowText()?);
+		///         Ok(())
 		///     }
 		/// });
 		/// ```
