@@ -2,8 +2,7 @@ use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::enums::HwndPlace;
-use crate::funcs::PostQuitMessage;
+use crate::enums::{AccelMenuCtrl, AccelMenuCtrlData, HwndPlace};
 use crate::gui::events::ButtonEvents;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
 use crate::gui::privs::{auto_ctrl_id, calc_text_bound_box_check, multiply_dpi, ui_font};
@@ -12,6 +11,21 @@ use crate::handles::HWND;
 use crate::msg::{bm, wm};
 use crate::structs::{POINT, SIZE};
 
+/// Possible states of a [`CheckBox`](crate::gui::CheckBox) control.
+#[derive(Clone, Copy, PartialEq, Eq)]
+pub enum CheckState {
+	/// CheckBox is checked.
+	Checked,
+	/// CheckBox is grayed, indicating an indeterminate state. Applicable only
+	/// if the CheckBox was created with [`BS::R3STATE`](crate::co::BS::R3STATE)
+	/// or [`BS::AUTO3STATE`](crate::co::BS::AUTO3STATE) styles.
+	Indeterminate,
+	/// CheckBox is cleared.
+	Unchecked,
+}
+
+//------------------------------------------------------------------------------
+
 /// Native
 /// [check box](https://docs.microsoft.com/en-us/windows/win32/controls/button-types-and-styles#check-boxes)
 /// control, actually a variation of the ordinary
@@ -27,7 +41,11 @@ struct Obj { // actual fields of CheckBox
 	events: ButtonEvents,
 }
 
-impl_send_sync_debug_child!(CheckBox);
+unsafe impl Send for CheckBox {}
+unsafe impl Sync for CheckBox {}
+
+impl_debug!(CheckBox);
+impl_child!(CheckBox);
 
 impl CheckBox {
 	/// Instantiates a new `CheckBox` object, to be created on the parent window
@@ -49,7 +67,7 @@ impl CheckBox {
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -72,41 +90,40 @@ impl CheckBox {
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					if opts.baseline_text_align { pos.y += 3; }
-					multiply_dpi(Some(&mut pos), None)?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				multiply_dpi(Some(&mut pos), None)?;
 
-					let mut sz = opts.size;
-					if sz.cx == -1 && sz.cy == -1 {
-						sz = calc_text_bound_box_check(&opts.text)?; // resize to fit text
-					} else {
-						multiply_dpi(None, Some(&mut sz))?; // user-defined size
-					}
+				let mut sz = opts.size;
+				if sz.cx == -1 && sz.cy == -1 {
+					sz = calc_text_bound_box_check(&opts.text)?; // resize to fit text
+				} else {
+					multiply_dpi(None, Some(&mut sz))?; // user-defined size
+				}
 
-					let our_hwnd = self.0.base.create_window( // may panic
-						"BUTTON", Some(&opts.text), pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.button_style.into(),
-					)?;
+				let our_hwnd = self.0.base.create_window( // may panic
+					"BUTTON", Some(&opts.text), pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.button_style.into(),
+				)?;
 
-					our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
-					if opts.checked { self.set_check(true); }
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
+				if opts.check_state != CheckState::Unchecked {
+					self.set_check_state(opts.check_state);
+				}
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -115,10 +132,27 @@ impl CheckBox {
 	pub_fn_onsubclass!();
 	pub_fn_on!(ButtonEvents);
 
-	/// Tells if this check box is currently checked by sending a
+	/// Retrieves the current check state by sending a
 	/// [`bm::GetCheck`](crate::msg::bm::GetCheck) message.
+	pub fn check_state(&self) -> CheckState {
+		match self.hwnd().SendMessage(bm::GetCheck {}) {
+			co::BST::CHECKED => CheckState::Checked,
+			co::BST::INDETERMINATE => CheckState::Indeterminate,
+			_ => CheckState::Unchecked,
+		}
+	}
+
+	/// Emulates the click event for the check box by sending a
+	/// [`bm::Click`](crate::msg::bm::Click) message.
+	pub fn emulate_click(&self) {
+		self.hwnd().SendMessage(bm::Click {});
+	}
+
+	/// Calls [`check_state`](crate::gui::CheckBox::check_state) and compares
+	/// the result with
+	/// [`CheckState::Checked`](crate::gui::CheckState::Checked).
 	pub fn is_checked(&self) -> bool {
-		self.hwnd().SendMessage(bm::GetCheck {}) == co::BST::CHECKED
+		self.check_state() == CheckState::Checked
 	}
 
 	/// Resizes the control to exactly fit current text.
@@ -128,9 +162,30 @@ impl CheckBox {
 
 	/// Sets the current check state by sending a
 	/// [`bm::SetCheck`](crate::msg::bm::SetCheck) message.
-	pub fn set_check(&self, checked: bool) {
+	pub fn set_check_state(&self, state: CheckState) {
 		self.hwnd().SendMessage(bm::SetCheck {
-			state: if checked { co::BST::CHECKED } else { co::BST::UNCHECKED },
+			state: match state {
+				CheckState::Checked => co::BST::CHECKED,
+				CheckState::Indeterminate => co::BST::INDETERMINATE,
+				CheckState::Unchecked => co::BST::UNCHECKED,
+			},
+		});
+	}
+
+	/// Sets the current check state by sending a
+	/// [`bm::SetCheck`](crate::msg::bm::SetCheck) message, then sends a
+	/// [`wm::Command`](crate::msg::wm::Command) message to the parent, so it
+	/// can handle the event.
+	pub fn set_check_state_and_trigger(&self, state: CheckState) {
+		self.set_check_state(state);
+		self.hwnd().SendMessage(wm::Command {
+			event: AccelMenuCtrl::Ctrl(
+				AccelMenuCtrlData {
+					notif_code: co::BN::CLICKED.into(),
+					ctrl_id: self.ctrl_id(),
+					ctrl_hwnd: self.hwnd(),
+				},
+			),
 		});
 	}
 
@@ -152,16 +207,10 @@ impl CheckBox {
 		self.hwnd().GetWindowText()
 	}
 
-	/// Fires the click event for the check box by sending a
-	/// [`bm::Click`](crate::msg::bm::Click) message.
-	pub fn trigger_click(&self) {
-		self.hwnd().SendMessage(bm::Click {});
-	}
-
 	fn resize_to_given_text(&self, text: &str) -> WinResult<()> {
 		let bound_box = calc_text_bound_box_check(text)?;
 		self.hwnd().SetWindowPos(
-			HwndPlace::None, 0, 0, bound_box.cx, bound_box.cy,
+			HwndPlace::None, POINT::default(), bound_box,
 			co::SWP::NOZORDER | co::SWP::NOMOVE)
 	}
 }
@@ -190,11 +239,6 @@ pub struct CheckBoxOpts {
 	///
 	/// Defaults to the size needed to fit the text.
 	pub size: SIZE,
-	/// Will adjust `position.cy` so that, if the control is placed side-by-side
-	/// with an [`Edit`](crate::gui::Edit) control, their texts will be aligned.
-	///
-	/// Defaults to false.
-	pub baseline_text_align: bool,
 	/// Check box styles to be
 	/// [created](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createwindowexw).
 	///
@@ -219,10 +263,10 @@ pub struct CheckBoxOpts {
 	/// Defaults to an auto-generated ID.
 	pub ctrl_id: u16,
 
-	/// Checks the check box right away.
+	/// Initial check state.
 	///
-	/// Defaults to `false`.
-	pub checked: bool,
+	/// Defaults to `CheckState::Unchecked`.
+	pub check_state: CheckState,
 }
 
 impl Default for CheckBoxOpts {
@@ -231,12 +275,11 @@ impl Default for CheckBoxOpts {
 			text: "".to_owned(),
 			position: POINT::new(0, 0),
 			size: SIZE::new(-1, -1), // will resize to fit the text
-			baseline_text_align: false,
 			button_style: co::BS::AUTOCHECKBOX,
 			window_style: co::WS::CHILD | co::WS::VISIBLE | co::WS::TABSTOP | co::WS::GROUP,
 			window_ex_style: co::WS_EX::LEFT,
 			ctrl_id: 0,
-			checked: false,
+			check_state: CheckState::Unchecked,
 		}
 	}
 }
