@@ -1,8 +1,8 @@
+use std::marker::PhantomData;
 use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::PostQuitMessage;
 use crate::gui::events::ComboBoxEvents;
 use crate::gui::native_controls::combo_box_items::ComboBoxItems;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
@@ -24,10 +24,13 @@ struct Obj { // actual fields of ComboBox
 	base: BaseNativeControl,
 	opts_id: OptsId<ComboBoxOpts>,
 	events: ComboBoxEvents,
-	items: ComboBoxItems,
 }
 
-impl_send_sync_debug_child!(ComboBox);
+unsafe impl Send for ComboBox {}
+unsafe impl Sync for ComboBox {}
+
+impl_debug!(ComboBox);
+impl_child!(ComboBox);
 
 impl ComboBox {
 	/// Instantiates a new `ComboBox` object, to be created on the parent window
@@ -43,15 +46,13 @@ impl ComboBox {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Wnd(opts),
 					events: ComboBoxEvents::new(parent_base_ref, ctrl_id),
-					items: ComboBoxItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -68,45 +69,40 @@ impl ComboBox {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Dlg(ctrl_id),
 					events: ComboBoxEvents::new(parent_base_ref, ctrl_id),
-					items: ComboBoxItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					let mut sz = SIZE::new(opts.width as _, 0);
-					if opts.baseline_text_align { pos.y -= 1; }
-					multiply_dpi(Some(&mut pos), Some(&mut sz))?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				let mut sz = SIZE::new(opts.width as _, 0);
+				multiply_dpi(Some(&mut pos), Some(&mut sz))?;
 
-					let our_hwnd = self.0.base.create_window( // may panic
-						"COMBOBOX", None, pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.combo_box_style.into(),
-					)?;
+				let our_hwnd = self.0.base.create_window( // may panic
+					"COMBOBOX", None, pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.combo_box_style.into(),
+				)?;
 
-					our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
+				our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
 
-					self.items().add(&opts.items)?;
-					self.items().set_selected(opts.selected_item);
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				self.items().add(&opts.items)?;
+				self.items().set_selected(opts.selected_item);
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -116,8 +112,11 @@ impl ComboBox {
 	pub_fn_on!(ComboBoxEvents);
 
 	/// Item methods.
-	pub fn items(&self) -> &ComboBoxItems {
-		&self.0.items
+	pub fn items<'a>(&'a self) -> ComboBoxItems<'a> {
+		ComboBoxItems {
+			hwnd: self.hwnd(),
+			owner: PhantomData,
+		}
 	}
 }
 
@@ -133,11 +132,6 @@ pub struct ComboBoxOpts {
 	///
 	/// Defaults to 0 x 0.
 	pub position: POINT,
-	/// Will adjust `position.cy` so that, if the control is placed side-by-side
-	/// with an [`Edit`](crate::gui::Edit) control, their texts will be aligned.
-	///
-	/// Defaults to false.
-	pub baseline_text_align: bool,
 	/// Control width, in pixels, to be
 	/// [created](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createwindowexw).
 	///
@@ -184,7 +178,6 @@ impl Default for ComboBoxOpts {
 	fn default() -> Self {
 		Self {
 			position: POINT::new(0, 0),
-			baseline_text_align: false,
 			width: 120,
 			ctrl_id: 0,
 			combo_box_style: co::CBS::DROPDOWNLIST,
