@@ -2,7 +2,6 @@ use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::PostQuitMessage;
 use crate::gui::events::EditEvents;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
 use crate::gui::privs::{auto_ctrl_id, multiply_dpi, ui_font};
@@ -25,7 +24,11 @@ struct Obj { // actual fields of Edit
 	events: EditEvents,
 }
 
-impl_send_sync_debug_child!(Edit);
+unsafe impl Send for Edit {}
+unsafe impl Sync for Edit {}
+
+impl_debug!(Edit);
+impl_child!(Edit);
 
 impl Edit {
 	/// Instantiates a new `Edit` object, to be created on the parent window
@@ -47,7 +50,7 @@ impl Edit {
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -70,33 +73,31 @@ impl Edit {
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					let mut sz = SIZE::new(opts.width as _, opts.height as _);
-					multiply_dpi(Some(&mut pos), Some(&mut sz))?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				let mut sz = SIZE::new(opts.width as _, opts.height as _);
+				multiply_dpi(Some(&mut pos), Some(&mut sz))?;
 
-					let our_hwnd = self.0.base.create_window( // may panic
-						"EDIT", Some(&opts.text), pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.edit_style.into(),
-					)?;
+				let our_hwnd = self.0.base.create_window( // may panic
+					"EDIT", Some(&opts.text), pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.edit_style.into(),
+				)?;
 
-					our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -143,7 +144,7 @@ impl Edit {
 	///
 	/// let my_edit: gui::Edit; // initialized somewhere
 	///
-	/// my_edit.set_text("This my text").unwrap();
+	/// my_edit.set_text("This my text")?;
 	/// ```
 	pub fn set_text(&self, text: &str) -> WinResult<()> {
 		self.hwnd().SetWindowText(text)
@@ -157,7 +158,7 @@ impl Edit {
 	///
 	/// let my_edit: gui::Edit; // initialized somewhere
 	///
-	/// println!("The text is: {}", my_edit.text().unwrap());
+	/// println!("The text is: {}", my_edit.text()?);
 	/// ```
 	pub fn text(&self) -> WinResult<String> {
 		self.hwnd().GetWindowText()
