@@ -3,7 +3,6 @@ use std::sync::Arc;
 use crate::aliases::WinResult;
 use crate::co;
 use crate::enums::HwndPlace;
-use crate::funcs::PostQuitMessage;
 use crate::gui::events::LabelEvents;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
 use crate::gui::privs::{auto_ctrl_id, calc_text_bound_box, multiply_dpi, ui_font};
@@ -26,7 +25,11 @@ struct Obj { // actual fields of Label
 	events: LabelEvents,
 }
 
-impl_send_sync_debug_child!(Label);
+unsafe impl Send for Label {}
+unsafe impl Sync for Label {}
+
+impl_debug!(Label);
+impl_child!(Label);
 
 impl Label {
 	/// Instantiates a new `Label` object, to be created on the parent window
@@ -48,7 +51,7 @@ impl Label {
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -71,40 +74,37 @@ impl Label {
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					if opts.baseline_text_align { pos.y += 3; }
-					multiply_dpi(Some(&mut pos), None)?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				multiply_dpi(Some(&mut pos), None)?;
 
-					let mut sz = opts.size;
-					if sz.cx == -1 && sz.cy == -1 {
-						sz = calc_text_bound_box(&opts.text)?; // resize to fit text
-					} else {
-						multiply_dpi(None, Some(&mut sz))?; // user-defined size
-					}
+				let mut sz = opts.size;
+				if sz.cx == -1 && sz.cy == -1 {
+					sz = calc_text_bound_box(&opts.text)?; // resize to fit text
+				} else {
+					multiply_dpi(None, Some(&mut sz))?; // user-defined size
+				}
 
-					let our_hwnd = self.0.base.create_window( // may panic
-						"STATIC", Some(&opts.text), pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.label_style.into(),
-					)?;
+				let our_hwnd = self.0.base.create_window( // may panic
+					"STATIC", Some(&opts.text), pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.label_style.into(),
+				)?;
 
-					our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -126,7 +126,7 @@ impl Label {
 	///
 	/// let my_label: gui::Label; // initialized somewhere
 	///
-	/// my_label.set_text("This my text").unwrap();
+	/// my_label.set_text("This my text")?;
 	/// ```
 	pub fn set_text(&self, text: &str) -> WinResult<()> {
 		self.hwnd().SetWindowText(text)
@@ -142,7 +142,7 @@ impl Label {
 	///
 	/// let my_label: gui::Label; // initialized somewhere
 	///
-	/// my_label.set_text_and_resize("This my text").unwrap();
+	/// my_label.set_text_and_resize("This my text")?;
 	/// ```
 	pub fn set_text_and_resize(&self, text: &str) -> WinResult<()> {
 		self.set_text(text)?;
@@ -159,7 +159,7 @@ impl Label {
 	///
 	/// let my_label: gui::Label; // initialized somewhere
 	///
-	/// println!("The text is: {}", my_label.text().unwrap());
+	/// println!("The text is: {}", my_label.text()?);
 	/// ```
 	pub fn text(&self) -> WinResult<String> {
 		self.hwnd().GetWindowText()
@@ -168,7 +168,7 @@ impl Label {
 	fn resize_to_given_text(&self, text: &str) -> WinResult<()> {
 		let bound_box = calc_text_bound_box(text)?;
 		self.hwnd().SetWindowPos(
-			HwndPlace::None, 0, 0, bound_box.cx, bound_box.cy,
+			HwndPlace::None, POINT::default(), bound_box,
 			co::SWP::NOZORDER | co::SWP::NOMOVE)
 	}
 }
@@ -197,11 +197,6 @@ pub struct LabelOpts {
 	///
 	/// Defaults to the size needed to fit the text.
 	pub size: SIZE,
-	/// Will adjust `position.cy` so that, if the control is placed side-by-side
-	/// with an [`Edit`](crate::gui::Edit) control, their texts will be aligned.
-	///
-	/// Defaults to false.
-	pub baseline_text_align: bool,
 	/// label styles to be
 	/// [created](https://docs.microsoft.com/en-us/windows/win32/api/winuser/nf-winuser-createwindowexw).
 	///
@@ -230,7 +225,6 @@ impl Default for LabelOpts {
 			text: "".to_owned(),
 			position: POINT::new(0, 0),
 			size: SIZE::new(-1, -1), // will resize to fit the text
-			baseline_text_align: false,
 			label_style: co::SS::LEFT | co::SS::NOTIFY,
 			window_style: co::WS::CHILD | co::WS::VISIBLE,
 			window_ex_style: co::WS_EX::LEFT,
