@@ -1,8 +1,8 @@
+use std::marker::PhantomData;
 use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::PostQuitMessage;
 use crate::gui::events::ListBoxEvents;
 use crate::gui::native_controls::list_box_items::ListBoxItems;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
@@ -25,10 +25,13 @@ struct Obj { // actual fields of ListBox
 	base: BaseNativeControl,
 	opts_id: OptsId<ListBoxOpts>,
 	events: ListBoxEvents,
-	items: ListBoxItems,
 }
 
-impl_send_sync_debug_child!(ListBox);
+unsafe impl Send for ListBox {}
+unsafe impl Sync for ListBox {}
+
+impl_debug!(ListBox);
+impl_child!(ListBox);
 
 impl ListBox {
 	/// Instantiates a new `ListBox` object, to be created on the parent window
@@ -44,15 +47,13 @@ impl ListBox {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Wnd(opts),
 					events: ListBoxEvents::new(parent_base_ref, ctrl_id),
-					items: ListBoxItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -69,42 +70,38 @@ impl ListBox {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Dlg(ctrl_id),
 					events: ListBoxEvents::new(parent_base_ref, ctrl_id),
-					items: ListBoxItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					let mut sz = opts.size;
-					multiply_dpi(Some(&mut pos), Some(&mut sz))?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				let mut sz = opts.size;
+				multiply_dpi(Some(&mut pos), Some(&mut sz))?;
 
-					let our_hwnd = self.0.base.create_window( // may panic
-						"ListBox", None, pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.list_box_style.into(),
-					)?;
+				let our_hwnd = self.0.base.create_window( // may panic
+					"ListBox", None, pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.list_box_style.into(),
+				)?;
 
-					our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
-					self.items().add(&opts.items)?;
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				our_hwnd.SendMessage(wm::SetFont{ hfont: ui_font(), redraw: true });
+				self.items().add(&opts.items)?;
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -114,8 +111,11 @@ impl ListBox {
 	pub_fn_on!(ListBoxEvents);
 
 	/// Item methods.
-	pub fn items(&self) -> &ListBoxItems {
-		&self.0.items
+	pub fn items<'a>(&'a self) -> ListBoxItems<'a> {
+		ListBoxItems {
+			hwnd: self.hwnd(),
+			owner: PhantomData,
+		}
 	}
 }
 
