@@ -1,5 +1,4 @@
-use std::cell::Cell;
-use std::ptr::NonNull;
+use std::marker::PhantomData;
 
 use crate::aliases::WinResult;
 use crate::handles::HWND;
@@ -10,25 +9,12 @@ use crate::various::WString;
 ///
 /// You cannot directly instantiate this object, it is created internally by the
 /// control.
-pub struct ListBoxItems {
-	hwnd_ptr: Cell<NonNull<HWND>>,
+pub struct ListBoxItems<'a> {
+	pub(in crate::gui::native_controls) hwnd: HWND,
+	pub(in crate::gui::native_controls) owner: PhantomData<&'a ()>,
 }
 
-impl ListBoxItems {
-	pub(in crate::gui::native_controls) fn new() -> ListBoxItems {
-		Self {
-			hwnd_ptr: Cell::new(NonNull::from(&HWND::NULL)), // initially invalid
-		}
-	}
-
-	pub(in crate::gui::native_controls) fn set_hwnd_ref(&self, hwnd_ref: &HWND) {
-		self.hwnd_ptr.replace(NonNull::from(hwnd_ref));
-	}
-
-	pub(in crate::gui::native_controls) fn hwnd(&self) -> HWND {
-		unsafe { *self.hwnd_ptr.get().as_ref() }
-	}
-
+impl<'a> ListBoxItems<'a> {
 	/// Adds new texts by sending [`lb::AddString`](crate::msg::lb::AddString)
 	/// messages.
 	///
@@ -43,7 +29,7 @@ impl ListBoxItems {
 	/// ```
 	pub fn add<S: AsRef<str>>(&self, items: &[S]) -> WinResult<()> {
 		for text in items.iter() {
-			self.hwnd().SendMessage(lb::AddString {
+			self.hwnd.SendMessage(lb::AddString {
 				text: WString::from_str(text.as_ref()),
 			})?;
 		}
@@ -53,19 +39,19 @@ impl ListBoxItems {
 	/// Retrieves the number of items by sending an
 	/// [`lb::GetCount`](crate::msg::lb::GetCount) message.
 	pub fn count(&self) -> WinResult<u32> {
-		self.hwnd().SendMessage(lb::GetCount {})
+		self.hwnd.SendMessage(lb::GetCount {})
 	}
 
 	/// Deletes the item at the given index by sending an
 	/// [`lb::DeleteString`](crate::msg::lb::DeleteString) message.
 	pub fn delete(&self, index: u32) -> WinResult<()> {
-		self.hwnd().SendMessage(lb::DeleteString { index })
+		self.hwnd.SendMessage(lb::DeleteString { index })
 			.map(|_| ())
 	}
 
 	/// Deletes all items by sending an
 	/// [`lb::ResetContent`](crate::msg::lb::ResetContent) message.
 	pub fn delete_all(&self) {
-		self.hwnd().SendMessage(lb::ResetContent {})
+		self.hwnd.SendMessage(lb::ResetContent {})
 	}
 }
