@@ -1,8 +1,9 @@
+use std::marker::PhantomData;
 use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::{GetAsyncKeyState, GetCursorPos, PostQuitMessage};
+use crate::funcs::{GetAsyncKeyState, GetCursorPos};
 use crate::gui::base::Base;
 use crate::gui::events::ListViewEvents;
 use crate::gui::native_controls::list_view_columns::ListViewColumns;
@@ -11,8 +12,8 @@ use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId
 use crate::gui::privs::{auto_ctrl_id, multiply_dpi};
 use crate::gui::traits::{baseref_from_parent, Parent};
 use crate::handles::{HIMAGELIST, HMENU, HWND};
-use crate::msg::lvm;
-use crate::structs::{LVHITTESTINFO, NMITEMACTIVATE, NMLVKEYDOWN, POINT, SIZE};
+use crate::msg::{lvm, wm};
+use crate::structs::{NMITEMACTIVATE, NMLVKEYDOWN, POINT, SIZE};
 
 /// Native
 /// [list view](https://docs.microsoft.com/en-us/windows/win32/controls/list-view-controls-overview)
@@ -27,12 +28,14 @@ struct Obj { // actual fields of ListView
 	base: BaseNativeControl,
 	opts_id: OptsId<ListViewOpts>,
 	events: ListViewEvents,
-	columns: ListViewColumns,
-	items: ListViewItems,
 	context_menu: Option<HMENU>,
 }
 
-impl_send_sync_debug_child!(ListView);
+unsafe impl Send for ListView {}
+unsafe impl Sync for ListView {}
+
+impl_debug!(ListView);
+impl_child!(ListView);
 
 impl ListView {
 	/// Instantiates a new `ListView` object, to be created on the parent window
@@ -49,18 +52,14 @@ impl ListView {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Wnd(opts),
 					events: ListViewEvents::new(parent_base_ref, ctrl_id),
-					columns: ListViewColumns::new(),
-					items: ListViewItems::new(),
 					context_menu,
 				},
 			),
 		);
-		new_self.0.columns.set_hwnd_ref(new_self.0.base.hwnd_ref());
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self.handled_events(parent_base_ref, ctrl_id);
@@ -86,49 +85,43 @@ impl ListView {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Dlg(ctrl_id),
 					events: ListViewEvents::new(parent_base_ref, ctrl_id),
-					columns: ListViewColumns::new(),
-					items: ListViewItems::new(),
 					context_menu,
 				},
 			),
 		);
-		new_self.0.columns.set_hwnd_ref(new_self.0.base.hwnd_ref());
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self.handled_events(parent_base_ref, ctrl_id);
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					let mut sz = opts.size;
-					multiply_dpi(Some(&mut pos), Some(&mut sz))?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				let mut sz = opts.size;
+				multiply_dpi(Some(&mut pos), Some(&mut sz))?;
 
-					self.0.base.create_window( // may panic
-						"SysListView32", None, pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.list_view_style.into(),
-					)?;
+				self.0.base.create_window( // may panic
+					"SysListView32", None, pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.list_view_style.into(),
+				)?;
 
-					if opts.list_view_ex_style != co::LVS_EX::NoValue {
-						self.toggle_extended_style(true, opts.list_view_ex_style);
-					}
+				if opts.list_view_ex_style != co::LVS_EX::NoValue {
+					self.set_extended_style(true, opts.list_view_ex_style);
+				}
 
-					self.columns().add(&opts.columns)?;
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				self.columns().add(&opts.columns)?;
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	fn handled_events(&self, parent_base_ref: &Base, ctrl_id: u16) {
@@ -140,12 +133,11 @@ impl ListView {
 				let has_shift = GetAsyncKeyState(co::VK::SHIFT);
 
 				if has_ctrl && lvnk.wVKey == co::VK('A' as _) { // Ctrl+A
-					me.items().set_selected_all(true)
-						.unwrap_or_else(|err| PostQuitMessage(err));
+					me.items().set_selected_all(true)?;
 				} else if lvnk.wVKey == co::VK::APPS { // context menu key
-					me.show_context_menu(false, has_ctrl, has_shift).unwrap();
+					me.show_context_menu(false, has_ctrl, has_shift)?;
 				}
-				None
+				Ok(None)
 			}
 		});
 
@@ -156,8 +148,8 @@ impl ListView {
 				let has_ctrl = nmia.uKeyFlags.has(co::LVKF::CONTROL);
 				let has_shift = nmia.uKeyFlags.has(co::LVKF::SHIFT);
 
-				me.show_context_menu(true, has_ctrl, has_shift).unwrap();
-				None
+				me.show_context_menu(true, has_ctrl, has_shift)?;
+				Ok(None)
 			}
 		});
 	}
@@ -169,8 +161,11 @@ impl ListView {
 	pub_fn_on!(ListViewEvents);
 
 	/// Exposes the column methods.
-	pub fn columns(&self) -> &ListViewColumns {
-		&self.0.columns
+	pub fn columns<'a>(&'a self) -> ListViewColumns<'a> {
+		ListViewColumns {
+			hwnd: self.hwnd(),
+			owner: PhantomData,
+		}
 	}
 
 	/// Returns the context menu attached to this list view, if any.
@@ -189,8 +184,11 @@ impl ListView {
 	}
 
 	/// Exposes the item methods.
-	pub fn items(&self) -> &ListViewItems {
-		&self.0.items
+	pub fn items<'a>(&'a self) -> ListViewItems<'a> {
+		ListViewItems {
+			hwnd: self.hwnd(),
+			owner: PhantomData,
+		}
 	}
 
 	/// Retrieves the current view by sending an
@@ -205,6 +203,16 @@ impl ListView {
 		self.hwnd().SendMessage(lvm::SetView { view })
 	}
 
+	/// Sets or unsets the given extended list view styles by sending an
+	/// [`lvm::SetExtendedListViewStyle`](crate::msg::lvm::SetExtendedListViewStyle)
+	/// message.
+	pub fn set_extended_style(&self, set: bool, ex_style: co::LVS_EX) {
+		self.hwnd().SendMessage(lvm::SetExtendedListViewStyle {
+			mask: ex_style,
+			style: if set { ex_style } else { co::LVS_EX::NoValue },
+		});
+	}
+
 	/// Sets the one of the associated image lists by sending an
 	/// [`lvm::SetImageList`](crate::msg::lvm::SetImageList) message.
 	///
@@ -215,14 +223,10 @@ impl ListView {
 		self.hwnd().SendMessage(lvm::SetImageList { kind, himagelist })
 	}
 
-	/// Toggles the given extended list view styles by sending an
-	/// [`lvm::SetExtendedListViewStyle`](crate::msg::lvm::SetExtendedListViewStyle)
-	/// message.
-	pub fn toggle_extended_style(&self, set: bool, ex_style: co::LVS_EX) {
-		self.hwnd().SendMessage(lvm::SetExtendedListViewStyle {
-			mask: ex_style,
-			style: if set { ex_style } else { co::LVS_EX::NoValue },
-		});
+	/// Allows or disallows the redrawing of the control by sending a
+	/// [`wm::SetRedraw`](crate::msg::wm::SetRedraw) message.
+	pub fn set_redraw(&self, can_redraw: bool) {
+		self.hwnd().SendMessage(wm::SetRedraw { can_redraw });
 	}
 
 	fn show_context_menu(&self,
@@ -237,32 +241,27 @@ impl ListView {
 			let mut menu_pos = GetCursorPos()?; // relative to screen
 			self.hwnd().ScreenToClient(&mut menu_pos)?; // now relative to list view
 
-			let mut lvhti = LVHITTESTINFO::default(); // find item below cursor, if any
-			lvhti.pt = menu_pos;
-
-			match self.items().hit_test(&mut lvhti) {
-				Some(idx) => { // an item was right-clicked
+			match self.items().hit_test(menu_pos) {
+				Some(item_over) => {
 					if !has_ctrl && !has_shift {
-						if !self.items().is_selected(idx) {
-							self.items().set_selected_all(false)?;
-							self.items().set_selected(true, &[idx])?;
-						}
-						self.items().set_focused(idx)?;
+						item_over.set_selected(true)?; // if not yet
+						item_over.set_focused()?;
 					}
 				},
 				None => { // no item was right-clicked
 					self.items().set_selected_all(false)?;
 				},
 			}
+
 			self.hwnd().SetFocus(); // because a right-click won't set the focus by itself
 			menu_pos
 
 		} else { // usually fired by the context meny key
-			let focused_idx_opt = self.items().focused();
+			let focused_opt = self.items().focused();
 
-			if focused_idx_opt.is_some() && self.items().is_visible(focused_idx_opt.unwrap()) {
-				let focused_idx = focused_idx_opt.unwrap();
-				let rc_item = self.items().rect(focused_idx, co::LVIR::BOUNDS)?;
+			if focused_opt.is_some() && focused_opt.unwrap().is_visible() {
+				let focused = focused_opt.unwrap();
+				let rc_item = focused.rect(co::LVIR::BOUNDS)?;
 				POINT::new(rc_item.left + 16,
 					rc_item.top + (rc_item.bottom - rc_item.top) / 2)
 
