@@ -1,8 +1,8 @@
 use std::ops::Index;
 use std::sync::Arc;
 
+use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::PostQuitMessage;
 use crate::gui::{RadioButton, RadioButtonOpts};
 use crate::gui::events::RadioGroupEvents;
 use crate::gui::traits::{baseref_from_parent, Child, Parent};
@@ -67,7 +67,7 @@ impl RadioGroup {
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -102,17 +102,17 @@ impl RadioGroup {
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
+	fn create(&self) -> WinResult<()> {
 		for radio in self.0.as_mut().radios.iter_mut() {
-			radio.create()
-				.unwrap_or_else(|err| PostQuitMessage(err));
+			radio.create()?;
 		}
+		Ok(())
 	}
 
 	/// Exposes the radio group events.
@@ -149,7 +149,7 @@ impl RadioGroup {
 	/// let radio_group: RadioGroup; // initialized somewhere
 	///
 	/// for single_radio in me.rads.iter() {
-	///     single_radio.hwnd().SetWindowText("One").unwrap();
+	///     single_radio.hwnd().SetWindowText("One")?;
 	/// }
 	/// ```
 	pub fn iter(&self) -> std::slice::Iter<'_, RadioButton> {
@@ -170,11 +170,11 @@ impl RadioGroup {
 		self.checked_index().map(|idx| &self.0.radios[idx])
 	}
 
-	/// Returns the index of the currently checked
+	/// Returns the index of the currently selected
 	/// [`RadioButton`](crate::gui::RadioButton) of this group, if any.
 	pub fn checked_index(&self) -> Option<usize> {
 		for (idx, radio) in self.0.radios.iter().enumerate() {
-			if radio.is_checked() {
+			if radio.is_selected() {
 				return Some(idx);
 			}
 		}
