@@ -1,8 +1,8 @@
+use std::marker::PhantomData;
 use std::sync::Arc;
 
 use crate::aliases::WinResult;
 use crate::co;
-use crate::funcs::PostQuitMessage;
 use crate::gui::events::TreeViewEvents;
 use crate::gui::native_controls::base_native_control::{BaseNativeControl, OptsId};
 use crate::gui::native_controls::tree_view_items::TreeViewItems;
@@ -24,10 +24,13 @@ struct Obj { // actual fields of TreeView
 	base: BaseNativeControl,
 	opts_id: OptsId<TreeViewOpts>,
 	events: TreeViewEvents,
-	items: TreeViewItems,
 }
 
-impl_send_sync_debug_child!(TreeView);
+unsafe impl Send for TreeView {}
+unsafe impl Sync for TreeView {}
+
+impl_debug!(TreeView);
+impl_child!(TreeView);
 
 impl TreeView {
 	/// Instantiates a new `TreeView` object, to be created on the parent window
@@ -43,15 +46,13 @@ impl TreeView {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Wnd(opts),
 					events: TreeViewEvents::new(parent_base_ref, ctrl_id),
-					items: TreeViewItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
 			let me = new_self.clone();
-			move |_| { me.create(); 0 }
+			move |_| { me.create()?; Ok(0) }
 		});
 
 		new_self
@@ -68,43 +69,39 @@ impl TreeView {
 					base: BaseNativeControl::new(parent_base_ref),
 					opts_id: OptsId::Dlg(ctrl_id),
 					events: TreeViewEvents::new(parent_base_ref, ctrl_id),
-					items: TreeViewItems::new(),
 				},
 			),
 		);
-		new_self.0.items.set_hwnd_ref(new_self.0.base.hwnd_ref());
 
 		parent_base_ref.privileged_events_ref().wm_init_dialog({
 			let me = new_self.clone();
-			move |_| { me.create(); true }
+			move |_| { me.create()?; Ok(true) }
 		});
 
 		new_self
 	}
 
-	fn create(&self) {
-		|| -> WinResult<()> {
-			match &self.0.opts_id {
-				OptsId::Wnd(opts) => {
-					let mut pos = opts.position;
-					let mut sz = opts.size;
-					multiply_dpi(Some(&mut pos), Some(&mut sz))?;
+	fn create(&self) -> WinResult<()> {
+		match &self.0.opts_id {
+			OptsId::Wnd(opts) => {
+				let mut pos = opts.position;
+				let mut sz = opts.size;
+				multiply_dpi(Some(&mut pos), Some(&mut sz))?;
 
-					self.0.base.create_window( // may panic
-						"SysTreeView32", None, pos, sz,
-						opts.ctrl_id,
-						opts.window_ex_style,
-						opts.window_style | opts.tree_view_style.into(),
-					)?;
+				self.0.base.create_window( // may panic
+					"SysTreeView32", None, pos, sz,
+					opts.ctrl_id,
+					opts.window_ex_style,
+					opts.window_style | opts.tree_view_style.into(),
+				)?;
 
-					if opts.tree_view_ex_style != co::TVS_EX::NoValue {
-						self.toggle_extended_style(true, opts.tree_view_ex_style)?;
-					}
-					Ok(())
-				},
-				OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
-			}
-		}().unwrap_or_else(|err| PostQuitMessage(err))
+				if opts.tree_view_ex_style != co::TVS_EX::NoValue {
+					self.set_extended_style(true, opts.tree_view_ex_style)?;
+				}
+				Ok(())
+			},
+			OptsId::Dlg(ctrl_id) => self.0.base.create_dlg(*ctrl_id).map(|_| ()), // may panic
+		}
 	}
 
 	pub_fn_hwnd!();
@@ -114,13 +111,16 @@ impl TreeView {
 	pub_fn_on!(TreeViewEvents);
 
 	/// Exposes the item methods.
-	pub fn items(&self) -> &TreeViewItems {
-		&self.0.items
+	pub fn items<'a>(&'a self) -> TreeViewItems<'a> {
+		TreeViewItems {
+			hwnd: self.hwnd(),
+			owner: PhantomData,
+		}
 	}
 
-	/// Toggles the given extended list view styles by sending a
+	/// Sets or unsets the given extended list view styles by sending a
 	/// [`tvm::SetExtendedStyle`](crate::msg::tvm::SetExtendedStyle) message.
-	pub fn toggle_extended_style(&self,
+	pub fn set_extended_style(&self,
 		set: bool, ex_style: co::TVS_EX) -> WinResult<()>
 	{
 		self.hwnd().SendMessage(tvm::SetExtendedStyle {
