@@ -1,9 +1,10 @@
-use crate::aliases::WinResult;
+use crate::aliases::{BoxResult, WinResult};
 use crate::co;
 use crate::enums::{AtomStr, IdIdcStr, IdMenu};
-use crate::funcs::{PostQuitMessage, RegisterClassEx, SetLastError};
+use crate::funcs::{RegisterClassEx, SetLastError};
 use crate::gui::base::Base;
 use crate::gui::events::ProcessResult;
+use crate::gui::privs::post_quit_error;
 use crate::handles::{HBRUSH, HCURSOR, HICON, HINSTANCE, HWND};
 use crate::msg::{MsgSendRecv, wm, WndMsg};
 use crate::structs::{ATOM, POINT, SIZE, WNDCLASSEX};
@@ -117,7 +118,7 @@ impl RawBase {
 			ex_styles,
 			AtomStr::Atom(class_name),
 			title, styles,
-			pos.x, pos.y, sz.cx, sz.cy,
+			pos, sz,
 			self.base.parent_base_ref().map(|parent| *parent.hwnd_ref()),
 			hmenu,
 			self.base.parent_hinstance()?,
@@ -129,54 +130,58 @@ impl RawBase {
 		self.base.ui_thread_message_handler();
 	}
 
-	pub(in crate::gui) fn run_ui_thread<F: FnOnce()>(&self, func: F) {
+	pub(in crate::gui) fn run_ui_thread<F>(&self, func: F)
+		where F: FnOnce() -> BoxResult<()>,
+	{
 		self.base.run_ui_thread(func);
 	}
 
 	extern "system" fn window_proc(
 		hwnd: HWND, msg: co::WM, wparam: usize, lparam: isize) -> isize
 	{
-		|hwnd: HWND, msg, wparam, lparam| -> WinResult<isize>
-		{
-			let wm_any = WndMsg { msg_id: msg, wparam, lparam };
+		Self::window_proc_proc(hwnd, msg, wparam, lparam)
+			.unwrap_or_else(|err| { post_quit_error(err); 0 })
+	}
 
-			let ptr_self = match msg {
-				co::WM::NCCREATE => { // first message being handled
-					let wm_ncc = wm::NcCreate::from_generic_wm(wm_any);
-					let ptr_self = wm_ncc.createstruct.lpCreateParams as *mut Self;
-					hwnd.SetWindowLongPtr(co::GWLP::USERDATA, ptr_self as _); // store
-					let ref_self = unsafe { &mut *ptr_self };
-					ref_self.base.set_hwnd(hwnd); // store HWND in struct field
-					ptr_self
-				},
-				_ => hwnd.GetWindowLongPtr(co::GWLP::USERDATA) as *mut Self, // retrieve
-			};
+	fn window_proc_proc(
+		hwnd: HWND, msg: co::WM, wparam: usize, lparam: isize) -> BoxResult<isize>
+	{
+		let wm_any = WndMsg { msg_id: msg, wparam, lparam };
 
-			// If no pointer stored, then no processing is done.
-			// Prevents processing before WM_NCCREATE and after WM_NCDESTROY.
-			if ptr_self.is_null() {
-				return Ok(hwnd.DefWindowProc(wm_any));
-			}
+		let ptr_self = match msg {
+			co::WM::NCCREATE => { // first message being handled
+				let wm_ncc = wm::NcCreate::from_generic_wm(wm_any);
+				let ptr_self = wm_ncc.createstruct.lpCreateParams as *mut Self;
+				hwnd.SetWindowLongPtr(co::GWLP::USERDATA, ptr_self as _); // store
+				let ref_self = unsafe { &mut *ptr_self };
+				ref_self.base.set_hwnd(hwnd); // store HWND in struct field
+				ptr_self
+			},
+			_ => hwnd.GetWindowLongPtr(co::GWLP::USERDATA) as *mut Self, // retrieve
+		};
 
-			// Execute privileged closures.
-			let ref_self = unsafe { &mut *ptr_self };
-			ref_self.base.process_privileged_messages(wm_any);
-
-			// Execute user closure, if any.
-			let process_result = ref_self.base.process_effective_message(wm_any);
-
-			if msg == co::WM::NCDESTROY { // always check
-				hwnd.SetWindowLongPtr(co::GWLP::USERDATA, 0); // clear passed pointer
-				ref_self.base.set_hwnd(HWND::NULL); // clear stored HWND
-			}
-
-			Ok(match process_result {
-				ProcessResult::HandledWithRet(res) => res,
-				ProcessResult::HandledWithoutRet => 0,
-				ProcessResult::NotHandled => hwnd.DefWindowProc(wm_any).into(),
-			})
+		// If no pointer stored, then no processing is done.
+		// Prevents processing before WM_NCCREATE and after WM_NCDESTROY.
+		if ptr_self.is_null() {
+			return Ok(hwnd.DefWindowProc(wm_any));
 		}
-		(hwnd, msg, wparam, lparam)
-			.unwrap_or_else(|err| { PostQuitMessage(err); 0 })
+
+		// Execute privileged closures.
+		let ref_self = unsafe { &mut *ptr_self };
+		ref_self.base.process_privileged_messages(wm_any)?;
+
+		// Execute user closure, if any.
+		let process_result = ref_self.base.process_one_message(wm_any)?;
+
+		if msg == co::WM::NCDESTROY { // always check
+			hwnd.SetWindowLongPtr(co::GWLP::USERDATA, 0); // clear passed pointer
+			ref_self.base.set_hwnd(HWND::NULL); // clear stored HWND
+		}
+
+		Ok(match process_result {
+			ProcessResult::HandledWithRet(res) => res,
+			ProcessResult::HandledWithoutRet => 0,
+			ProcessResult::NotHandled => hwnd.DefWindowProc(wm_any).into(),
+		})
 	}
 }
