@@ -1,6 +1,6 @@
 use std::sync::Arc;
 
-use crate::aliases::WinResult;
+use crate::aliases::BoxResult;
 use crate::co;
 use crate::enums::IdMenu;
 use crate::funcs::{AdjustWindowRectEx, GetSystemMetrics, PostQuitMessage};
@@ -41,12 +41,14 @@ impl RawMain {
 		self.0.base.base_ref()
 	}
 
-	pub(in crate::gui) fn run_ui_thread<F: FnOnce()>(&self, func: F) {
+	pub(in crate::gui) fn run_ui_thread<F>(&self, func: F)
+		where F: FnOnce() -> BoxResult<()>,
+	{
 		self.0.base.run_ui_thread(func);
 	}
 
 	pub(in crate::gui) fn run_main(&self,
-		cmd_show: Option<co::SW>) -> WinResult<()>
+		cmd_show: Option<co::SW>) -> BoxResult<i32>
 	{
 		let opts = &self.0.opts;
 
@@ -84,11 +86,7 @@ impl RawMain {
 		self.0.base.create_window( // may panic
 			atom,
 			Some(&opts.title),
-			if opts.menu.is_null() {
-				IdMenu::None
-			} else {
-				IdMenu::Menu(opts.menu)
-			},
+			if opts.menu.is_null() { IdMenu::None } else { IdMenu::Menu(opts.menu) },
 			POINT::new(wnd_rc.left, wnd_rc.top), wnd_sz,
 			opts.ex_style, opts.style,
 		)?;
@@ -97,12 +95,13 @@ impl RawMain {
 		hwnd.ShowWindow(cmd_show.unwrap_or(co::SW::SHOW));
 		hwnd.UpdateWindow()?;
 
-		let res = Base::run_main_loop(opts.accel_table.as_opt()); // blocks until window is closed
+		let loop_ret = Base::run_main_loop(opts.accel_table.as_opt()); // blocks until window is closed
 
 		if let Some(haccel) = opts.accel_table.as_opt() {
 			haccel.DestroyAcceleratorTable();
 		}
-		res
+
+		loop_ret
 	}
 
 	fn default_message_handlers(&self) {
@@ -120,6 +119,7 @@ impl RawMain {
 						hwnd_prev_focus.SetFocus(); // put focus back
 					}
 				}
+				Ok(())
 			}
 		});
 
@@ -131,11 +131,14 @@ impl RawMain {
 						self2.0.base.focus_first_child(); // if window receives focus, delegate to first child
 					}
 				}
+				Ok(())
 			}
 		});
 
-		self.base_ref().user_events_ref().wm_nc_destroy(
-			|| PostQuitMessage(co::ERROR::SUCCESS));
+		self.base_ref().user_events_ref().wm_nc_destroy(|| {
+			PostQuitMessage(0);
+			Ok(())
+		});
 	}
 }
 
