@@ -1,6 +1,6 @@
 use std::sync::Arc;
 
-use crate::aliases::WinResult;
+use crate::aliases::{BoxResult, WinResult};
 use crate::co;
 use crate::enums::IdMenu;
 use crate::funcs::{
@@ -49,7 +49,9 @@ impl RawModal {
 		self.0.base.base_ref()
 	}
 
-	pub(in crate::gui) fn run_ui_thread<F: FnOnce()>(&self, func: F) {
+	pub(in crate::gui) fn run_ui_thread<F>(&self, func: F)
+		where F: FnOnce() -> BoxResult<()>,
+	{
 		self.0.base.run_ui_thread(func);
 	}
 
@@ -104,8 +106,8 @@ impl RawModal {
 				// WM_QUIT was sent, exit modal loop now and signal parent.
 				// wParam has the program exit code.
 				// https://devblogs.microsoft.com/oldnewthing/20050222-00/?p=36393
-				PostQuitMessage(co::ERROR(msg.wParam as u32));
-				return Ok(msg.wParam as i32);
+				PostQuitMessage(msg.wParam as _);
+				return Ok(msg.wParam as _);
 			}
 
 			// If a child window, will retrieve its top-level parent.
@@ -141,6 +143,7 @@ impl RawModal {
 						self2.0.base.focus_first_child(); // if window receives focus, delegate to first child
 					}
 				}
+				Ok(())
 			}
 		});
 
@@ -150,11 +153,12 @@ impl RawModal {
 				let hwnd = *self2.base_ref().hwnd_ref();
 				if let Ok(hparent) = hwnd.GetWindow(co::GW::OWNER) {
 					hparent.EnableWindow(true); // re-enable parent
-					hwnd.DestroyWindow(); // then destroy modal
+					hwnd.DestroyWindow()?; // then destroy modal
 					if let Some(hprev) = self2.0.hchild_prev_focus_parent {
 						hprev.SetFocus(); // this focus could be set on WM_DESTROY as well
 					}
 				}
+				Ok(())
 			}
 		});
 	}
