@@ -5,13 +5,12 @@ use std::sync::Arc;
 use crate::aliases::WinResult;
 use crate::co;
 use crate::enums::HwndPlace;
-use crate::funcs::PostQuitMessage;
 use crate::gui::base::Base;
 use crate::gui::traits::{baseref_from_parent, Child, Parent};
 use crate::gui::very_unsafe_cell::VeryUnsafeCell;
 use crate::handles::{HDWP, HWND};
 use crate::msg::wm;
-use crate::structs::{RECT, SIZE};
+use crate::structs::{POINT, RECT, SIZE};
 
 /// In [`Resizer::new`](crate::gui::Resizer::new), determines how the child
 /// controls will be adjusted automatically when the parent window is resized.
@@ -27,19 +26,13 @@ pub enum Resz {
 	Resize,
 }
 
-struct Ctrl {
+struct Ctrl { // each child control kept internally in the Resizer
 	hwnd_ptr: NonNull<HWND>,
 	rc_orig: RECT, // original coordinates relative to parent
 	horz: Resz,
 	vert: Resz,
 }
 
-struct ChildEntry { // parameters passed to constructor
-	horz: Resz,
-	vert: Resz,
-	children: Vec<NonNull<HWND>>,
-}
-
 //------------------------------------------------------------------------------
 
 /// When the parent window is resized, automatically adjusts position and size
@@ -114,59 +107,58 @@ impl Resizer {
 
 		let ptr_parent = NonNull::from(parent_base_ref);
 		let rc_children = Rc::new(
-			children.iter().map(|c|
-				ChildEntry {
-					horz: c.0,
-					vert: c.1,
-					children: c.2.iter()
+			children.iter().map(|(horz, vert, children)|
+				(
+					*horz,
+					*vert,
+					children.iter()
 						.map(|dyn_child| NonNull::from(dyn_child.hwnd_ref()))
 						.collect(),
-				},
-			).collect::<Vec<_>>()
+				),
+			).collect::<Vec<_>>(),
 		);
 
 		parent_base_ref.privileged_events_ref().wm(parent_base_ref.creation_wm(), {
+			// Children are effectively added during WM_CREATE or WM_INITDIALOG.
 			let me = new_self.clone();
-			move |_| { me.add_children(ptr_parent, rc_children.clone()); 0 }
+			move |_| { me.add_children(ptr_parent, rc_children.clone())?; Ok(0) }
 		});
 		parent_base_ref.privileged_events_ref().wm_size({
+			// Children are resized/repositioned during WM_SIZE.
 			let me = new_self.clone();
-			move |p| me.resize(&p).unwrap_or_else(|err| PostQuitMessage(err))
+			move |p| { me.resize(&p)?; Ok(()) }
 		});
 
 		new_self
 	}
 
 	fn add_children(&self,
-		ptr_parent: NonNull<Base>, rc_children: Rc<Vec<ChildEntry>>)
+		ptr_parent: NonNull<Base>,
+		rc_children: Rc<Vec<(Resz, Resz, Vec<NonNull<HWND>>)>>) -> WinResult<()>
 	{
 		let ctrls = &mut self.0.as_mut().ctrls;
 		ctrls.reserve(rc_children.len());
 
-		|ptr_parent: NonNull<Base>, rc_children: Rc<Vec<ChildEntry>>| -> WinResult<()> {
-			let parent_base_ref = unsafe { ptr_parent.as_ref() };
-			let rc_parent = parent_base_ref.hwnd_ref().GetClientRect()?;
-			self.0.as_mut().sz_parent_orig = SIZE::new(rc_parent.right, rc_parent.bottom); // save original parent size
+		let parent_base_ref = unsafe { ptr_parent.as_ref() };
+		let rc_parent = parent_base_ref.hwnd_ref().GetClientRect()?;
+		self.0.as_mut().sz_parent_orig = SIZE::new(rc_parent.right, rc_parent.bottom); // save original parent size
 
-			for entry in rc_children.iter() {
-				for child_hwnd_ptr in entry.children.iter() {
-					let child_hwnd_ref = unsafe { child_hwnd_ptr.as_ref() };
-					let mut rc_orig = child_hwnd_ref.GetWindowRect()?;
-					parent_base_ref.hwnd_ref().ScreenToClientRc(&mut rc_orig)?; // control client coordinates relative to parent
+		for (horz, vert, children) in rc_children.iter() {
+			for child_hwnd_ptr in children.iter() {
+				let child_hwnd_ref = unsafe { child_hwnd_ptr.as_ref() };
+				let mut rc_orig = child_hwnd_ref.GetWindowRect()?;
+				parent_base_ref.hwnd_ref().ScreenToClientRc(&mut rc_orig)?; // control client coordinates relative to parent
 
-					ctrls.push(Ctrl {
-						hwnd_ptr: *child_hwnd_ptr,
-						rc_orig,
-						horz: entry.horz,
-						vert: entry.vert,
-					});
-				}
+				ctrls.push(Ctrl {
+					hwnd_ptr: *child_hwnd_ptr,
+					rc_orig,
+					horz: *horz,
+					vert: *vert,
+				});
 			}
-
-			Ok(())
 		}
-		(ptr_parent, rc_children)
-			.unwrap_or_else(|err| { PostQuitMessage(err); });
+
+		Ok(())
 	}
 
 	/// Resizes all registered children according to the defined rules.
@@ -191,22 +183,26 @@ impl Resizer {
 			hdwp.DeferWindowPos(
 				unsafe { *ctrl.hwnd_ptr.as_ref() },
 				HwndPlace::None,
-				match ctrl.horz {
-					Resz::Repos => parent_cx - self.0.sz_parent_orig.cx + ctrl.rc_orig.left,
-					_ => ctrl.rc_orig.left // keep original x pos
-				},
-				match ctrl.vert {
-					Resz::Repos => parent_cy - self.0.sz_parent_orig.cy + ctrl.rc_orig.top,
-					_ => ctrl.rc_orig.top // keep original y pos
-				},
-				match ctrl.horz {
-					Resz::Resize => parent_cx - self.0.sz_parent_orig.cx + ctrl.rc_orig.right - ctrl.rc_orig.left,
-					_ => ctrl.rc_orig.right - ctrl.rc_orig.left // keep original width
-				},
-				match ctrl.vert {
-					Resz::Resize => parent_cy - self.0.sz_parent_orig.cy + ctrl.rc_orig.bottom - ctrl.rc_orig.top,
-					_ =>ctrl.rc_orig.bottom - ctrl.rc_orig.top // keep original height
-				},
+				POINT::new(
+					match ctrl.horz {
+						Resz::Repos => parent_cx - self.0.sz_parent_orig.cx + ctrl.rc_orig.left,
+						_ => ctrl.rc_orig.left // keep original x pos
+					},
+					match ctrl.vert {
+						Resz::Repos => parent_cy - self.0.sz_parent_orig.cy + ctrl.rc_orig.top,
+						_ => ctrl.rc_orig.top // keep original y pos
+					},
+				),
+				SIZE::new(
+					match ctrl.horz {
+						Resz::Resize => parent_cx - self.0.sz_parent_orig.cx + ctrl.rc_orig.right - ctrl.rc_orig.left,
+						_ => ctrl.rc_orig.right - ctrl.rc_orig.left // keep original width
+					},
+					match ctrl.vert {
+						Resz::Resize => parent_cy - self.0.sz_parent_orig.cy + ctrl.rc_orig.bottom - ctrl.rc_orig.top,
+						_ =>ctrl.rc_orig.bottom - ctrl.rc_orig.top // keep original height
+					},
+				),
 				uflags,
 			)?;
 		}
