@@ -1,4 +1,4 @@
-use crate::aliases::WinResult;
+use crate::aliases::BoxResult;
 use crate::co;
 use crate::funcs::{InitCommonControls, IsWindowsVistaOrGreater, SetProcessDPIAware};
 use crate::gui::base::Base;
@@ -41,7 +41,7 @@ enum RawDlg { Raw(RawMain), Dlg(DlgMain) }
 /// ```rust,ignore
 /// #![windows_subsystem = "windows"]
 ///
-/// use winsafe::{gui, msg, WinResult};
+/// use winsafe::{gui, msg, BoxResult};
 ///
 /// fn main() {
 ///     let my_main = MyMain::new();
@@ -71,9 +71,10 @@ enum RawDlg { Raw(RawMain), Dlg(DlgMain) }
 ///     fn events(&self) {
 ///         self.wnd.on().wm_l_button_down({
 ///             let wnd = self.wnd.clone(); // clone to pass it to the closure
-///             move |p: msg::wm::LButtonDown| {
+///             move |p: msg::wm::LButtonDown| -> BoxResult<()> {
 ///                 let txt = &format!("Coords {} x {}", p.coords.x, p.coords.y);
-///                 wnd.hwnd().SetWindowText(txt).unwrap();
+///                 wnd.hwnd().SetWindowText(txt)?;
+///                 Ok(())
 ///             }
 ///         });
 ///     }
@@ -87,11 +88,10 @@ enum RawDlg { Raw(RawMain), Dlg(DlgMain) }
 /// instead of creating the window programmatically. Note how
 /// `WindowMain::new_dlg` instead of `WindowMain::new`.
 ///
-///
 /// ```rust,ignore
 /// #![windows_subsystem = "windows"]
 ///
-/// use winsafe::{gui, WinResult};
+/// use winsafe::gui;
 ///
 /// const ID_DLG_MAIN: i32 = 101; // in our .res file, this is the dialog ID
 ///
@@ -125,7 +125,11 @@ pub struct WindowMain {
 	raw_dlg: RawDlg,
 }
 
-impl_send_sync_debug_parent!(WindowMain);
+unsafe impl Send for WindowMain {}
+unsafe impl Sync for WindowMain {}
+
+impl_debug!(WindowMain);
+impl_parent!(WindowMain);
 
 impl WindowMain {
 	/// Instantiates a new `WindowMain` object, to be created with
@@ -152,7 +156,10 @@ impl WindowMain {
 		}
 	}
 
-	pub_fn_baseref_hwnd_on_runuithread!();
+	fn_base_ref!();
+	pub_fn_hwnd!();
+	pub_fn_on!();
+	pub_fn_run_ui_thread!();
 
 	/// Physically creates the window, then runs the main application loop. This
 	/// method will block until the window is closed.
@@ -163,7 +170,7 @@ impl WindowMain {
 	/// # Panics
 	///
 	/// Panics if the window is already created.
-	pub fn run_main(&self, cmd_show: Option<co::SW>) -> WinResult<()> {
+	pub fn run_main(&self, cmd_show: Option<co::SW>) -> BoxResult<i32> {
 		if IsWindowsVistaOrGreater()? {
 			SetProcessDPIAware()?;
 		}
@@ -171,11 +178,12 @@ impl WindowMain {
 		InitCommonControls();
 		create_ui_font()?;
 
-		match &self.raw_dlg {
-			RawDlg::Raw(r) => r.run_main(cmd_show)?,
-			RawDlg::Dlg(d) => d.run_main(cmd_show)?,
-		}
+		let res = match &self.raw_dlg {
+			RawDlg::Raw(r) => r.run_main(cmd_show),
+			RawDlg::Dlg(d) => d.run_main(cmd_show),
+		};
 
-		delete_ui_font() // cleanup
+		delete_ui_font()?; // cleanup
+		res
 	}
 }
