@@ -1,10 +1,6 @@
 #![allow(non_snake_case)]
 
-pub_struct_handle_gdi! {
-	/// Handle to a
-	/// [bitmap](https://docs.microsoft.com/en-us/windows/win32/winprog/windows-data-types#hbitmap).
-	HBITMAP
-}
+use crate::aliases::WinResult;
 
 pub_struct_handle_closeable! {
 	/// Handle to an
