@@ -23,9 +23,9 @@ impl HDROP {
 	/// Retrieve all files at once:
 	///
 	/// ```rust.ignore
-	/// let files = hdrop.DragQueryFile().unwrap();
+	/// let files = hdrop.DragQueryFiles()?;
 	/// for f in files.iter() {
-	///   println!("File path: {}", f);
+	///     println!("File path: {}", f);
 	/// }
 	/// ```
 	pub fn DragQueryFiles(self) -> WinResult<Vec<String>> {
@@ -70,9 +70,9 @@ impl HDROP {
 	/// area of the window
 	pub fn DragQueryPoint(self) -> (POINT, bool) {
 		let mut pt = POINT::default();
-		let clientArea = unsafe {
+		let client_area = unsafe {
 			shell32::DragQueryPoint(self.ptr, &mut pt as *mut _ as _)
 		};
-		(pt, clientArea != 0)
+		(pt, client_area != 0)
 	}
 }
