@@ -21,17 +21,17 @@ impl HFILEMAP {
 	/// [`HFILEMAPVIEW::UnmapViewOfFile`](crate::HFILEMAPVIEW::UnmapViewOfFile)
 	/// call.
 	pub fn MapViewOfFile(self,
-		desiredAccess: co::FILE_MAP,
+		desired_access: co::FILE_MAP,
 		offset: u64,
-		numberOfBytesToMap: Option<i64>) -> WinResult<HFILEMAPVIEW>
+		number_of_bytes_to_map: Option<i64>) -> WinResult<HFILEMAPVIEW>
 	{
 		unsafe {
 			kernel32::MapViewOfFile(
 				self.ptr,
-				desiredAccess.0,
+				desired_access.0,
 				HIDWORD(offset),
 				LODWORD(offset),
-				numberOfBytesToMap.unwrap_or_default(),
+				number_of_bytes_to_map.unwrap_or_default(),
 			).as_mut()
 		}.map(|ptr| HFILEMAPVIEW { ptr })
 			.ok_or_else(|| GetLastError())
@@ -85,23 +85,23 @@ impl HFILEMAPVIEW {
 	///     co::DISPOSITION::OPEN_EXISTING,
 	///     co::FILE_ATTRIBUTE::NORMAL,
 	///     None,
-	/// ).unwrap();
+	/// )?;
 	///
 	/// let hmap = hfile.CreateFileMapping(
 	///     None,
 	///     co::PAGE::READONLY,
 	///     None,
 	///     None,
-	/// ).unwrap();
+	/// )?;
 	///
-	/// let view = hmap.MapViewOfFile(co::FILE_MAP::READ, 0, None).unwrap();
+	/// let view = hmap.MapViewOfFile(co::FILE_MAP::READ, 0, None)?;
 	///
-	/// let slice = view.as_slice(hfile.GetFileSizeEx().unwrap());
-	/// let text = std::str::from_utf8(slice).unwrap();
+	/// let slice = view.as_slice(hfile.GetFileSizeEx()?);
+	/// let text = std::str::from_utf8(slice)?;
 	///
-	/// view.UnmapViewOfFile().unwrap();
-	/// hmap.CloseHandle().unwrap();
-	/// hfile.CloseHandle().unwrap();
+	/// view.UnmapViewOfFile()?;
+	/// hmap.CloseHandle()?;
+	/// hfile.CloseHandle()?;
 	///
 	/// println!("{}", text);
 	/// ```
