@@ -6,7 +6,7 @@ use crate::ffi::comctl32;
 use crate::funcs::{GetLastError, SHGetFileInfo};
 use crate::handles::{HBITMAP, HICON};
 use crate::privs::bool_to_winresult;
-use crate::structs::{COLORREF, SHFILEINFO};
+use crate::structs::{COLORREF, POINT, SIZE, SHFILEINFO};
 
 pub_struct_handle! {
 	/// Handle to an
@@ -21,13 +21,13 @@ impl HIMAGELIST {
 	/// **Note:** A copy of the bitmap is made, and this copy is then stored.
 	/// You're still responsible for freeing the original bitmap.
 	pub fn Add(self,
-		hbmImage: HBITMAP, hbmMask: Option<HBITMAP>) -> WinResult<u32>
+		hbmp_image: HBITMAP, hbmp_mask: Option<HBITMAP>) -> WinResult<u32>
 	{
 		match unsafe {
 			comctl32::ImageList_Add(
 				self.ptr,
-				hbmImage.ptr,
-				hbmMask.map_or(std::ptr::null_mut(), |h| h.ptr),
+				hbmp_image.ptr,
+				hbmp_mask.map_or(std::ptr::null_mut(), |h| h.ptr),
 			)
 		} {
 			-1 => Err(GetLastError()),
@@ -48,28 +48,26 @@ impl HIMAGELIST {
 	/// # Examples
 	///
 	/// ```rust,ignore
-	/// use winsafe::{co, HIMAGELIST};
+	/// use winsafe::{co, HIMAGELIST, SIZE};
 	///
 	/// let himgl = HIMAGELIST::Create(
-	///     16, 16, co::ILC::COLOR32, 1, 1).unwrap();
+	///     SIZE::new(16, 16), co::ILC::COLOR32, 1, 1)?;
 	///
-	/// himgl.AddIconFromShell(&["mp3", "wav"]).unwrap();
+	/// himgl.AddIconFromShell(&["mp3", "wav"])?;
 	///
-	/// himgl.Destroy().unwrap();
+	/// himgl.Destroy()?;
 	/// ```
-	pub fn AddIconFromShell(self, fileExtensions: &[&str]) -> WinResult<()> {
-		let (cx, cy) = self.GetIconSize()?;
-		let isIco16 = cx == 16 && cy == 16;
-		let isIco32 = cx == 32 && cy == 32;
-		if !isIco16 && !isIco32 {
+	pub fn AddIconFromShell(self, file_extensions: &[&str]) -> WinResult<()> {
+		let sz = self.GetIconSize()?;
+		if !sz.is(16, 16) && !sz.is(32, 32) {
 			return Err(co::ERROR::NOT_SUPPORTED); // only 16x16 or 32x32 icons can be loaded
 		}
 
 		let mut shfi = SHFILEINFO::default();
-		for fileExtension in fileExtensions.iter() {
+		for fileExtension in file_extensions.iter() {
 			SHGetFileInfo(&format!("*.{}", fileExtension), co::FILE_ATTRIBUTE::NORMAL,
 				&mut shfi, co::SHGFI::USEFILEATTRIBUTES | co::SHGFI::ICON |
-				if isIco16 { co::SHGFI::SMALLICON } else { co::SHGFI::LARGEICON })?;
+				if sz.is(16, 16) { co::SHGFI::SMALLICON } else { co::SHGFI::LARGEICON })?;
 			self.AddIcon(shfi.hIcon)?;
 			shfi.hIcon.DestroyIcon()?;
 		}
@@ -79,10 +77,10 @@ impl HIMAGELIST {
 	/// [`ImageList_AddMasked`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_addmasked)
 	/// method.
 	pub fn AddMasked(self,
-		hbmImage: HBITMAP, crMask: COLORREF) -> WinResult<u32>
+		hbmp_image: HBITMAP, color_mask: COLORREF) -> WinResult<u32>
 	{
 		match unsafe {
-			comctl32::ImageList_AddMasked(self.ptr, hbmImage.ptr, crMask.0)
+			comctl32::ImageList_AddMasked(self.ptr, hbmp_image.ptr, color_mask.0)
 		} {
 			-1 => Err(GetLastError()),
 			idx => Ok(idx as _),
@@ -94,16 +92,13 @@ impl HIMAGELIST {
 	///
 	/// **Note:** Must be paired with an
 	/// [`HIMAGELIST::EndDrag`](crate::HIMAGELIST::EndDrag) call.
-	pub fn BeginDrag(self,
-		iTrack: u32, dxHotspot: i32, dyHotspot: i32) -> WinResult<()>
-	{
+	pub fn BeginDrag(self, track: u32, hotspot: POINT) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
 				comctl32::ImageList_BeginDrag(
 					self.ptr,
-					iTrack as _,
-					dxHotspot,
-					dyHotspot,
+					track as _,
+					hotspot.x, hotspot.y,
 				)
 			},
 		)
@@ -118,18 +113,24 @@ impl HIMAGELIST {
 	/// # Examples
 	///
 	/// ```rust,ignore
-	/// use winsafe::{co, HIMAGELIST};
+	/// use winsafe::{co, HIMAGELIST, SIZE};
 	///
 	/// let himgl = HIMAGELIST::Create(
-	///     16, 16, co::ILC::COLOR32, 1, 1).unwrap();
+	///     SIZE::new(16, 16), co::ILC::COLOR32, 1, 1)?;
 	///
-	/// himgl.Destroy().unwrap();
+	/// himgl.Destroy()?;
 	/// ```
-	pub fn Create(cx: i32, cy: i32,
-		flags: co::ILC, cInitial: i32, cGrow: i32) -> WinResult<HIMAGELIST>
+	pub fn Create(
+		image_sz: SIZE, flags: co::ILC,
+		initial_size: i32, grow_size: i32) -> WinResult<HIMAGELIST>
 	{
 		unsafe {
-			comctl32::ImageList_Create(cx, cy, flags.0, cInitial, cGrow).as_mut()
+			comctl32::ImageList_Create(
+				image_sz.cx, image_sz.cy,
+				flags.0,
+				initial_size,
+				grow_size,
+			).as_mut()
 		}.map(|ptr| Self { ptr })
 			.ok_or_else(|| GetLastError())
 	}
@@ -148,9 +149,9 @@ impl HIMAGELIST {
 
 	/// [`ImageList_DragShowNolock`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_dragshownolock)
 	/// static method.
-	pub fn DragShowNolock(fShow: bool) -> WinResult<()> {
+	pub fn DragShowNolock(show: bool) -> WinResult<()> {
 		bool_to_winresult(
-			unsafe { comctl32::ImageList_DragShowNolock(fShow as _) },
+			unsafe { comctl32::ImageList_DragShowNolock(show as _) },
 		)
 	}
 
@@ -162,11 +163,13 @@ impl HIMAGELIST {
 
 	/// [`ImageList_GetIconSize`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_geticonsize)
 	/// method.
-	pub fn GetIconSize(self) -> WinResult<(i32, i32)> {
-		let (mut cx, mut cy) = (0, 0);
+	pub fn GetIconSize(self) -> WinResult<SIZE> {
+		let mut sz = SIZE::default();
 		bool_to_winresult(
-			unsafe { comctl32::ImageList_GetIconSize(self.ptr, &mut cx, &mut cy) }
-		).map(|_| (cx, cy))
+			unsafe {
+				comctl32::ImageList_GetIconSize(self.ptr, &mut sz.cx, &mut sz.cy)
+			}
+		).map(|_| sz)
 	}
 
 	/// [`ImageList_GetImageCount`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_getimagecount)
@@ -177,12 +180,12 @@ impl HIMAGELIST {
 
 	/// [`ImageList_Remove`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_remove)
 	/// method.
-	pub fn Remove(self, i: Option<u32>) -> WinResult<()> {
+	pub fn Remove(self, index: Option<u32>) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
 				comctl32::ImageList_Remove(
 					self.ptr,
-					i.map_or(-1, |i| i as _),
+					index.map_or(-1, |i| i as _),
 				)
 			},
 		)
@@ -196,12 +199,14 @@ impl HIMAGELIST {
 
 	/// [`ImageList_ReplaceIcon`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_replaceicon)
 	/// method.
-	pub fn ReplaceIcon(self, i: Option<u32>, hicon: HICON) -> WinResult<u32> {
+	pub fn ReplaceIcon(self,
+		index: Option<u32>, hicon_new: HICON) -> WinResult<u32>
+	{
 		match unsafe {
 			comctl32::ImageList_ReplaceIcon(
 				self.ptr,
-				i.map_or(-1, |i| i as _),
-				hicon.ptr,
+				index.map_or(-1, |i| i as _),
+				hicon_new.ptr,
 			)
 		} {
 			-1 => Err(GetLastError()),
@@ -211,10 +216,10 @@ impl HIMAGELIST {
 
 	/// [`ImageList_SetImageCount`](https://docs.microsoft.com/en-us/windows/win32/api/commctrl/nf-commctrl-imagelist_setimagecount)
 	/// methods.
-	pub fn SetImageCount(self, uNewCount: u32) -> WinResult<()> {
+	pub fn SetImageCount(self, new_count: u32) -> WinResult<()> {
 		bool_to_winresult(
 			unsafe {
-				comctl32::ImageList_SetImageCount(self.ptr, uNewCount)
+				comctl32::ImageList_SetImageCount(self.ptr, new_count)
 			},
 		)
 	}
