@@ -5,6 +5,7 @@ mod macros;
 
 mod any_handles;
 mod haccel;
+mod hbitmap;
 mod hbrush;
 mod hcursor;
 mod hdc;
@@ -22,6 +23,7 @@ mod hinstance;
 mod hkey;
 mod hlocal;
 mod hmenu;
+mod hmonitor;
 mod hpen;
 mod hpipe;
 mod hprocess;
@@ -34,6 +36,7 @@ mod hwnd;
 
 pub use any_handles::*;
 pub use haccel::HACCEL;
+pub use hbitmap::HBITMAP;
 pub use hbrush::HBRUSH;
 pub use hcursor::HCURSOR;
 pub use hdc::HDC;
@@ -51,6 +54,7 @@ pub use hinstance::HINSTANCE;
 pub use hkey::HKEY;
 pub use hlocal::HLOCAL;
 pub use hmenu::HMENU;
+pub use hmonitor::HMONITOR;
 pub use hpen::HPEN;
 pub use hpipe::HPIPE;
 pub use hprocess::HPROCESS;
