@@ -5,17 +5,21 @@
 use crate::aliases::WinResult;
 use crate::co;
 use crate::funcs::{HIWORD, LOWORD, MAKEDWORD};
-use crate::handles::HWND;
+use crate::handles::{HIMAGELIST, HWND};
 use crate::msg::{MsgSend, WndMsg};
+use crate::msg::macros::{zero_as_err, zero_as_none};
 use crate::structs::{
 	COLORREF,
 	LVCOLUMN,
 	LVFINDINFO,
 	LVHITTESTINFO,
 	LVITEM,
+	LVITEMINDEX,
+	POINT,
 	RECT,
 	SIZE,
 };
+use crate::various::WString;
 
 /// [`LVM_APPROXIMATEVIEWRECT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-approximateviewrect)
 /// message parameters.
@@ -67,10 +71,7 @@ impl MsgSend for Arrange {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -96,10 +97,7 @@ impl MsgSend for DeleteAllItems {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -123,10 +121,7 @@ impl MsgSend for DeleteItem {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -151,10 +146,7 @@ impl MsgSend for EnsureVisible {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -229,10 +221,7 @@ impl<'a, 'b> MsgSend for GetColumn<'a, 'b> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -244,6 +233,30 @@ impl<'a, 'b> MsgSend for GetColumn<'a, 'b> {
 	}
 }
 
+/// [`LVM_GETCOLUMNORDERARRAY`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getcolumnorderarray)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct GetColumnOrderArray<'a> {
+	pub indexes: &'a mut Vec<u32>,
+}
+
+impl<'a> MsgSend for GetColumnOrderArray<'a> {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_err(v).map(|_| ())
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETCOLUMNORDERARRAY.into(),
+			wparam: self.indexes.len() as _,
+			lparam: self.indexes.as_ptr() as _,
+		}
+	}
+}
+
 /// [`LVM_GETCOLUMNWIDTH`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getcolumnwidth)
 /// message parameters.
 ///
@@ -271,6 +284,28 @@ impl MsgSend for GetColumnWidth {
 	}
 }
 
+/// [`LVM_GETCOUNTPERPAGE`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getcountperpage)
+/// message, which has no parameters.
+///
+/// Return type: `u32`.
+pub struct GetCountPerPage {}
+
+impl MsgSend for GetCountPerPage {
+	type RetType = u32;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v as _
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETCOUNTPERPAGE.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LVM_GETEXTENDEDLISTVIEWSTYLE`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getextendedlistviewstyle)
 /// message, which has no parameters.
 ///
@@ -303,10 +338,7 @@ impl MsgSend for GetHeader {
 	type RetType = WinResult<HWND>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			p => Ok(HWND { ptr: p as _ }),
-		}
+		zero_as_err(v).map(|p| HWND { ptr: p as _ })
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -318,6 +350,30 @@ impl MsgSend for GetHeader {
 	}
 }
 
+/// [`LVM_GETIMAGELIST`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getimagelist)
+/// message parameters.
+///
+/// Return type: `Option<HIMAGELIST>`.
+pub struct GetImageList {
+	pub kind: co::LVSIL,
+}
+
+impl MsgSend for GetImageList {
+	type RetType = Option<HIMAGELIST>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_none(v).map(|p| HIMAGELIST { ptr: p as _ })
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETIMAGELIST.into(),
+			wparam: self.kind.0 as _,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LVM_GETITEMCOUNT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getitemcount)
 /// message, which has no parameters.
 ///
@@ -390,6 +446,35 @@ impl<'a, 'b> MsgSend for GetItemText<'a, 'b> {
 	}
 }
 
+/// [`LVM_GETITEMRECT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getitemrect)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct GetItemRect<'a> {
+	pub index: u32,
+	pub rect: &'a mut RECT,
+	pub portion: co::LVIR,
+}
+
+impl<'a> MsgSend for GetItemRect<'a> {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_err(v).map(|_| ())
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		let ptr_rect = self.rect as *const _ as *mut RECT;
+		unsafe { &mut *ptr_rect }.left = self.portion.0 as _;
+
+		WndMsg {
+			msg_id: co::LVM::GETITEMRECT.into(),
+			wparam: self.index as _,
+			lparam: self.rect as *const _ as _,
+		}
+	}
+}
+
 /// [`LVM_GETNEXTITEM`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getnextitem)
 /// message parameters.
 ///
@@ -418,34 +503,122 @@ impl MsgSend for GetNextItem {
 	}
 }
 
-/// [`LVM_GETITEMRECT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getitemrect)
+/// [`LVM_GETNEXTITEMINDEX`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getnextitemindex)
 /// message parameters.
 ///
-/// Return type: `WinResult<()>`.
-pub struct GetItemRect<'a> {
-	pub index: u32,
-	pub rect: &'a mut RECT,
-	pub portion: co::LVIR,
+/// Return type: `bool`.
+pub struct GetNextItemIndex<'a> {
+	pub initial_item: &'a mut LVITEMINDEX,
+	pub relationship: co::LVNI,
 }
 
-impl<'a> MsgSend for GetItemRect<'a> {
-	type RetType = WinResult<()>;
+impl<'a> MsgSend for GetNextItemIndex<'a> {
+	type RetType = bool;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v != 0
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETNEXTITEMINDEX.into(),
+			wparam: self.initial_item as *const _ as _,
+			lparam: self.relationship.0 as _,
+		}
+	}
+}
+
+/// [`LVM_GETNUMBEROFWORKAREAS`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getnumberofworkareas)
+/// message parameters.
+///
+/// Return type: `()`.
+pub struct GetNumberOfWorkAreas<'a> {
+	pub num: &'a mut u32,
+}
+
+impl<'a> MsgSend for GetNumberOfWorkAreas<'a> {
+	type RetType = ();
+
+	fn convert_ret(&self, _: isize) -> Self::RetType {
+		()
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETNUMBEROFWORKAREAS.into(),
+			wparam: 0,
+			lparam: self.num as *const _ as _,
+		}
+	}
+}
+
+/// [`LVM_GETORIGIN`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getorigin)
+/// message parameters.
+///
+/// Return type: `bool`.
+pub struct GetOrigin<'a> {
+	pub origin: &'a mut POINT,
+}
+
+impl<'a> MsgSend for GetOrigin<'a> {
+	type RetType = bool;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v != 0
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETORIGIN.into(),
+			wparam: 0,
+			lparam: self.origin as *const _ as _,
+		}
+	}
+}
+
+/// [`LVM_GETOUTLINECOLOR`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getoutlinecolor)
+/// message, which has no parameters.
+///
+/// Return type: `COLORREF`.
+pub struct GetOutlineColor {}
+
+impl MsgSend for GetOutlineColor {
+	type RetType = COLORREF;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		COLORREF(v as _)
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETOUTLINECOLOR.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LVM_GETSELECTEDCOLUMN`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getselectedcolumn)
+/// message, which has no parameters.
+///
+/// Return type: `Option<u32>.
+pub struct GetSelectedColumn {}
+
+impl MsgSend for GetSelectedColumn {
+	type RetType = Option<u32>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
 		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
+			-1 => None,
+			idx => Some(idx as _),
 		}
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
-		let ptr_rect = self.rect as *const _ as *mut RECT;
-		unsafe { &mut *ptr_rect }.left = self.portion.0 as _;
-
 		WndMsg {
-			msg_id: co::LVM::GETITEMRECT.into(),
-			wparam: self.index as _,
-			lparam: self.rect as *const _ as _,
+			msg_id: co::LVM::GETSELECTEDCOLUMN.into(),
+			wparam: 0,
+			lparam: 0,
 		}
 	}
 }
@@ -472,6 +645,127 @@ impl MsgSend for GetSelectedCount {
 	}
 }
 
+/// [`LVM_GETSELECTIONMARK`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getselectionmark)
+/// message, which has no parameters.
+///
+/// Return type: `Option<u32>.
+pub struct GetSelectionMark {}
+
+impl MsgSend for GetSelectionMark {
+	type RetType = Option<u32>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v {
+			-1 => None,
+			idx => Some(idx as _),
+		}
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETSELECTIONMARK.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LVM_GETSTRINGWIDTH`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getstringwidth)
+/// message parameters.
+///
+/// Return type: `WinResult<u32>`.
+pub struct GetStringWidth {
+	pub text: WString,
+}
+
+impl MsgSend for GetStringWidth {
+	type RetType = WinResult<u32>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v {
+			0 => Err(co::ERROR::BAD_ARGUMENTS),
+			len => Ok(len as _),
+		}
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETSTRINGWIDTH.into(),
+			wparam: 0,
+			lparam: unsafe { self.text.as_ptr() } as _,
+		}
+	}
+}
+
+/// [`LVM_GETTEXTBKCOLOR`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-gettextbkcolor)
+/// message, which has no parameters.
+///
+/// Return type: `COLORREF`.
+pub struct GetTextBkColor {}
+
+impl MsgSend for GetTextBkColor {
+	type RetType = COLORREF;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		COLORREF(v as _)
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETTEXTBKCOLOR.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LVM_GETTEXTCOLOR`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-gettextcolor)
+/// message, which has no parameters.
+///
+/// Return type: `COLORREF`.
+pub struct GetTextColor {}
+
+impl MsgSend for GetTextColor {
+	type RetType = COLORREF;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		COLORREF(v as _)
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETTEXTCOLOR.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LVM_GETTOPINDEX`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-gettopindex)
+/// message, which has no parameters.
+///
+/// In case of error or when there are no items, this message returns zero, so
+/// other checks must be made.
+///
+/// Return type: `u32`.
+pub struct GetTopIndex {}
+
+impl MsgSend for GetTopIndex {
+	type RetType = u32;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		v as _
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETTOPINDEX.into(),
+			wparam: 0,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LVM_GETVIEW`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getview)
 /// message, which has no parameters.
 ///
@@ -493,6 +787,31 @@ impl MsgSend for GetView {
 		}
 	}
 }
+
+/// [`LVM_GETVIEWRECT`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-getviewrect)
+/// message parameters.
+///
+/// Return type: `WinResult<()>`.
+pub struct GetViewRect<'a> {
+	pub rect: &'a mut RECT,
+}
+
+impl<'a> MsgSend for GetViewRect<'a> {
+	type RetType = WinResult<()>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_err(v).map(|_| ())
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::GETVIEWRECT.into(),
+			wparam: 0,
+			lparam: self.rect as *const _ as _,
+		}
+	}
+}
+
 /// [`LVM_HITTEST`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-hittest)
 /// message parameters.
 ///
@@ -621,6 +940,60 @@ impl MsgSend for IsItemVisible {
 	}
 }
 
+/// [`LVM_MAPIDTOINDEX`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-mapidtoindex)
+/// message parameters.
+///
+/// Return type: `Option<u32>`.
+pub struct MapIdToIndex {
+	pub id: u32,
+}
+
+impl MsgSend for MapIdToIndex {
+	type RetType = Option<u32>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v {
+			-1 => None,
+			idx => Some(idx as _),
+		}
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::MAPIDTOINDEX.into(),
+			wparam: self.id as _,
+			lparam: 0,
+		}
+	}
+}
+
+/// [`LVM_MAPINDEXTOID`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-mapindextoid)
+/// message parameters.
+///
+/// Return type: `Option<u32>`.
+pub struct MapIndexToId {
+	pub index: u32,
+}
+
+impl MsgSend for MapIndexToId {
+	type RetType = Option<u32>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		match v {
+			-1 => None,
+			idx => Some(idx as _),
+		}
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::MAPINDEXTOID.into(),
+			wparam: self.index as _,
+			lparam: 0,
+		}
+	}
+}
+
 /// [`LVM_REDRAWITEMS`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-redrawitems)
 /// message parameters.
 ///
@@ -634,10 +1007,7 @@ impl MsgSend for RedrawItems {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -662,10 +1032,7 @@ impl MsgSend for Scroll {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -690,10 +1057,7 @@ impl<'a, 'b> MsgSend for SetColumn<'a, 'b> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -718,10 +1082,7 @@ impl MsgSend for SetColumnWidth {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -758,6 +1119,31 @@ impl MsgSend for SetExtendedListViewStyle {
 	}
 }
 
+/// [`LVM_SETIMAGELIST`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-setimagelist)
+/// message parameters.
+///
+/// Return type: `Option<HIMAGELIST>`.
+pub struct SetImageList {
+	pub kind: co::LVSIL,
+	pub himagelist: HIMAGELIST,
+}
+
+impl MsgSend for SetImageList {
+	type RetType = Option<HIMAGELIST>;
+
+	fn convert_ret(&self, v: isize) -> Self::RetType {
+		zero_as_none(v).map(|p| HIMAGELIST { ptr: p as _ })
+	}
+
+	fn as_generic_wm(&self) -> WndMsg {
+		WndMsg {
+			msg_id: co::LVM::SETIMAGELIST.into(),
+			wparam: self.kind.0 as _,
+			lparam: self.himagelist.ptr as _,
+		}
+	}
+}
+
 /// [`LVM_SETITEM`](https://docs.microsoft.com/en-us/windows/win32/controls/lvm-setitem)
 /// message parameters.
 ///
@@ -770,10 +1156,7 @@ impl<'a, 'b> MsgSend for SetItem<'a, 'b> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -798,10 +1181,7 @@ impl<'a, 'b> MsgSend for SetItemState<'a, 'b> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -826,10 +1206,7 @@ impl<'a, 'b> MsgSend for SetItemText<'a, 'b> {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
@@ -904,10 +1281,7 @@ impl MsgSend for Update {
 	type RetType = WinResult<()>;
 
 	fn convert_ret(&self, v: isize) -> Self::RetType {
-		match v {
-			0 => Err(co::ERROR::BAD_ARGUMENTS),
-			_ => Ok(()),
-		}
+		zero_as_err(v).map(|_| ())
 	}
 
 	fn as_generic_wm(&self) -> WndMsg {
