@@ -1,7 +1,9 @@
 mod ini;
+mod resource_info;
 mod mapped_file;
 mod w_string;
 
 pub use ini::*;
 pub use mapped_file::*;
+pub use resource_info::*;
 pub use w_string::*;
